# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetExpressSyncsSyncResult',
    'GetGatewayBlockVolumesVolumeResult',
    'GetGatewayCacheDisksDiskResult',
    'GetGatewayFileSharesShareResult',
    'GetGatewaySmbUsersUserResult',
    'GetGatewaysGatewayResult',
    'GetStocksStockResult',
    'GetStorageBundlesBundleResult',
]

@pulumi.output_type
class GetExpressSyncsSyncResult(dict):
    def __init__(__self__, *,
                 bucket_name: str,
                 bucket_prefix: str,
                 bucket_region: str,
                 description: str,
                 express_sync_id: str,
                 express_sync_name: str,
                 id: str,
                 mns_topic: str):
        """
        :param str bucket_name: The name of the OSS Bucket.
        :param str bucket_prefix: The prefix of the OSS Bucket.
        :param str bucket_region: The region of the OSS Bucket.
        :param str description: The description of the Express Sync.
        :param str express_sync_id: The ID of the Express Sync.
        :param str express_sync_name: The name of the Express Sync.
        :param str mns_topic: The name of the message topic (Topic) corresponding to the Express Sync in the Alibaba Cloud Message Service MNS.
        """
        pulumi.set(__self__, "bucket_name", bucket_name)
        pulumi.set(__self__, "bucket_prefix", bucket_prefix)
        pulumi.set(__self__, "bucket_region", bucket_region)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "express_sync_id", express_sync_id)
        pulumi.set(__self__, "express_sync_name", express_sync_name)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "mns_topic", mns_topic)

    @property
    @pulumi.getter(name="bucketName")
    def bucket_name(self) -> str:
        """
        The name of the OSS Bucket.
        """
        return pulumi.get(self, "bucket_name")

    @property
    @pulumi.getter(name="bucketPrefix")
    def bucket_prefix(self) -> str:
        """
        The prefix of the OSS Bucket.
        """
        return pulumi.get(self, "bucket_prefix")

    @property
    @pulumi.getter(name="bucketRegion")
    def bucket_region(self) -> str:
        """
        The region of the OSS Bucket.
        """
        return pulumi.get(self, "bucket_region")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of the Express Sync.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="expressSyncId")
    def express_sync_id(self) -> str:
        """
        The ID of the Express Sync.
        """
        return pulumi.get(self, "express_sync_id")

    @property
    @pulumi.getter(name="expressSyncName")
    def express_sync_name(self) -> str:
        """
        The name of the Express Sync.
        """
        return pulumi.get(self, "express_sync_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="mnsTopic")
    def mns_topic(self) -> str:
        """
        The name of the message topic (Topic) corresponding to the Express Sync in the Alibaba Cloud Message Service MNS.
        """
        return pulumi.get(self, "mns_topic")


@pulumi.output_type
class GetGatewayBlockVolumesVolumeResult(dict):
    def __init__(__self__, *,
                 address: str,
                 cache_mode: str,
                 chap_enabled: bool,
                 chap_in_user: str,
                 chunk_size: int,
                 disk_id: str,
                 disk_type: str,
                 enabled: bool,
                 gateway_block_volume_name: str,
                 gateway_id: str,
                 id: str,
                 index_id: str,
                 local_path: str,
                 lun_id: int,
                 oss_bucket_name: str,
                 oss_bucket_ssl: bool,
                 oss_endpoint: str,
                 port: int,
                 protocol: str,
                 size: int,
                 state: str,
                 status: int,
                 target: str,
                 total_download: int,
                 total_upload: int,
                 volume_state: int):
        """
        :param str address: The IP ADDRESS.
        :param str cache_mode: The Block volume set mode to cache mode. Value values: `Cache`, `WriteThrough`.
        :param bool chap_enabled: Whether to enable iSCSI access of CHAP authentication, which currently supports both CHAP inbound authentication.  Default value: `false`.
        :param str chap_in_user: The Inbound CHAP user.**NOTE:** When the `chap_enabled` is  `true` is,The `chap_in_password` is valid.
        :param int chunk_size: The Block volume storage allocation unit.  Valid values: `8192`, `16384`, `32768`, `65536`, `131072`. Default value: `32768`. Unit: `Byte`.
        :param str disk_id: The cache disk ID.
        :param str disk_type: The cache disk type.
        :param bool enabled: Whether to enable Volume.
        :param str gateway_block_volume_name: The Block volume name.  The name must be 1 to 32 characters in length, and can contain lowercase letters, numbers.
        :param str gateway_id: The Gateway ID.
        :param str id: The ID of the Gateway Block Volume. The value formats as `<gateway_id>:<index_id>`.
        :param str index_id: The ID of the index.
        :param str local_path: CThe Cache disk to local path. **NOTE:**  When the `cache_mode` is  `Cache` is,The `chap_in_password` is valid.
        :param int lun_id: The Lun identifier.
        :param str oss_bucket_name: The name of the OSS Bucket.
        :param bool oss_bucket_ssl: Whether to enable SSL access your OSS Buckets. Default value: `true`.
        :param str oss_endpoint: The endpoint of the OSS Bucket.
        :param int port: The Port.
        :param str protocol: The Protocol.
        :param int size: The Volume size.
        :param str state: The Buffer status.
        :param int status: The status of volume.
        :param str target: The target.
        :param int total_download: The total amount of downloaded data. Unit: `B`.
        :param int total_upload: The total amount of uploaded data. Unit: `B`.
        """
        pulumi.set(__self__, "address", address)
        pulumi.set(__self__, "cache_mode", cache_mode)
        pulumi.set(__self__, "chap_enabled", chap_enabled)
        pulumi.set(__self__, "chap_in_user", chap_in_user)
        pulumi.set(__self__, "chunk_size", chunk_size)
        pulumi.set(__self__, "disk_id", disk_id)
        pulumi.set(__self__, "disk_type", disk_type)
        pulumi.set(__self__, "enabled", enabled)
        pulumi.set(__self__, "gateway_block_volume_name", gateway_block_volume_name)
        pulumi.set(__self__, "gateway_id", gateway_id)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "index_id", index_id)
        pulumi.set(__self__, "local_path", local_path)
        pulumi.set(__self__, "lun_id", lun_id)
        pulumi.set(__self__, "oss_bucket_name", oss_bucket_name)
        pulumi.set(__self__, "oss_bucket_ssl", oss_bucket_ssl)
        pulumi.set(__self__, "oss_endpoint", oss_endpoint)
        pulumi.set(__self__, "port", port)
        pulumi.set(__self__, "protocol", protocol)
        pulumi.set(__self__, "size", size)
        pulumi.set(__self__, "state", state)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "target", target)
        pulumi.set(__self__, "total_download", total_download)
        pulumi.set(__self__, "total_upload", total_upload)
        pulumi.set(__self__, "volume_state", volume_state)

    @property
    @pulumi.getter
    def address(self) -> str:
        """
        The IP ADDRESS.
        """
        return pulumi.get(self, "address")

    @property
    @pulumi.getter(name="cacheMode")
    def cache_mode(self) -> str:
        """
        The Block volume set mode to cache mode. Value values: `Cache`, `WriteThrough`.
        """
        return pulumi.get(self, "cache_mode")

    @property
    @pulumi.getter(name="chapEnabled")
    def chap_enabled(self) -> bool:
        """
        Whether to enable iSCSI access of CHAP authentication, which currently supports both CHAP inbound authentication.  Default value: `false`.
        """
        return pulumi.get(self, "chap_enabled")

    @property
    @pulumi.getter(name="chapInUser")
    def chap_in_user(self) -> str:
        """
        The Inbound CHAP user.**NOTE:** When the `chap_enabled` is  `true` is,The `chap_in_password` is valid.
        """
        return pulumi.get(self, "chap_in_user")

    @property
    @pulumi.getter(name="chunkSize")
    def chunk_size(self) -> int:
        """
        The Block volume storage allocation unit.  Valid values: `8192`, `16384`, `32768`, `65536`, `131072`. Default value: `32768`. Unit: `Byte`.
        """
        return pulumi.get(self, "chunk_size")

    @property
    @pulumi.getter(name="diskId")
    def disk_id(self) -> str:
        """
        The cache disk ID.
        """
        return pulumi.get(self, "disk_id")

    @property
    @pulumi.getter(name="diskType")
    def disk_type(self) -> str:
        """
        The cache disk type.
        """
        return pulumi.get(self, "disk_type")

    @property
    @pulumi.getter
    def enabled(self) -> bool:
        """
        Whether to enable Volume.
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter(name="gatewayBlockVolumeName")
    def gateway_block_volume_name(self) -> str:
        """
        The Block volume name.  The name must be 1 to 32 characters in length, and can contain lowercase letters, numbers.
        """
        return pulumi.get(self, "gateway_block_volume_name")

    @property
    @pulumi.getter(name="gatewayId")
    def gateway_id(self) -> str:
        """
        The Gateway ID.
        """
        return pulumi.get(self, "gateway_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Gateway Block Volume. The value formats as `<gateway_id>:<index_id>`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="indexId")
    def index_id(self) -> str:
        """
        The ID of the index.
        """
        return pulumi.get(self, "index_id")

    @property
    @pulumi.getter(name="localPath")
    def local_path(self) -> str:
        """
        CThe Cache disk to local path. **NOTE:**  When the `cache_mode` is  `Cache` is,The `chap_in_password` is valid.
        """
        return pulumi.get(self, "local_path")

    @property
    @pulumi.getter(name="lunId")
    def lun_id(self) -> int:
        """
        The Lun identifier.
        """
        return pulumi.get(self, "lun_id")

    @property
    @pulumi.getter(name="ossBucketName")
    def oss_bucket_name(self) -> str:
        """
        The name of the OSS Bucket.
        """
        return pulumi.get(self, "oss_bucket_name")

    @property
    @pulumi.getter(name="ossBucketSsl")
    def oss_bucket_ssl(self) -> bool:
        """
        Whether to enable SSL access your OSS Buckets. Default value: `true`.
        """
        return pulumi.get(self, "oss_bucket_ssl")

    @property
    @pulumi.getter(name="ossEndpoint")
    def oss_endpoint(self) -> str:
        """
        The endpoint of the OSS Bucket.
        """
        return pulumi.get(self, "oss_endpoint")

    @property
    @pulumi.getter
    def port(self) -> int:
        """
        The Port.
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter
    def protocol(self) -> str:
        """
        The Protocol.
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter
    def size(self) -> int:
        """
        The Volume size.
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The Buffer status.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter
    def status(self) -> int:
        """
        The status of volume.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def target(self) -> str:
        """
        The target.
        """
        return pulumi.get(self, "target")

    @property
    @pulumi.getter(name="totalDownload")
    def total_download(self) -> int:
        """
        The total amount of downloaded data. Unit: `B`.
        """
        return pulumi.get(self, "total_download")

    @property
    @pulumi.getter(name="totalUpload")
    def total_upload(self) -> int:
        """
        The total amount of uploaded data. Unit: `B`.
        """
        return pulumi.get(self, "total_upload")

    @property
    @pulumi.getter(name="volumeState")
    def volume_state(self) -> int:
        return pulumi.get(self, "volume_state")


@pulumi.output_type
class GetGatewayCacheDisksDiskResult(dict):
    def __init__(__self__, *,
                 cache_disk_category: str,
                 cache_disk_size_in_gb: int,
                 cache_id: str,
                 expired_time: int,
                 gateway_id: str,
                 id: str,
                 iops: int,
                 is_used: bool,
                 local_file_path: str,
                 renew_url: str,
                 status: int):
        """
        :param str cache_disk_category: The category of eht cache disk.
        :param int cache_disk_size_in_gb: The size of the cache disk.
        :param str cache_id: The ID of the cache disk.
        :param int expired_time: The expiration time. Time stamp in seconds (s).
        :param str gateway_id: The ID of the gateway.
        :param str id: The ID of the Gateway Cache Disk.
        :param int iops: Per second of the input output.
        :param bool is_used: Whether it is used.
        :param str local_file_path: The cache disk inside the device name.
        :param str renew_url: A renewal link of the cache disk.
        :param int status: The status of the resource.
        """
        pulumi.set(__self__, "cache_disk_category", cache_disk_category)
        pulumi.set(__self__, "cache_disk_size_in_gb", cache_disk_size_in_gb)
        pulumi.set(__self__, "cache_id", cache_id)
        pulumi.set(__self__, "expired_time", expired_time)
        pulumi.set(__self__, "gateway_id", gateway_id)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "iops", iops)
        pulumi.set(__self__, "is_used", is_used)
        pulumi.set(__self__, "local_file_path", local_file_path)
        pulumi.set(__self__, "renew_url", renew_url)
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="cacheDiskCategory")
    def cache_disk_category(self) -> str:
        """
        The category of eht cache disk.
        """
        return pulumi.get(self, "cache_disk_category")

    @property
    @pulumi.getter(name="cacheDiskSizeInGb")
    def cache_disk_size_in_gb(self) -> int:
        """
        The size of the cache disk.
        """
        return pulumi.get(self, "cache_disk_size_in_gb")

    @property
    @pulumi.getter(name="cacheId")
    def cache_id(self) -> str:
        """
        The ID of the cache disk.
        """
        return pulumi.get(self, "cache_id")

    @property
    @pulumi.getter(name="expiredTime")
    def expired_time(self) -> int:
        """
        The expiration time. Time stamp in seconds (s).
        """
        return pulumi.get(self, "expired_time")

    @property
    @pulumi.getter(name="gatewayId")
    def gateway_id(self) -> str:
        """
        The ID of the gateway.
        """
        return pulumi.get(self, "gateway_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Gateway Cache Disk.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def iops(self) -> int:
        """
        Per second of the input output.
        """
        return pulumi.get(self, "iops")

    @property
    @pulumi.getter(name="isUsed")
    def is_used(self) -> bool:
        """
        Whether it is used.
        """
        return pulumi.get(self, "is_used")

    @property
    @pulumi.getter(name="localFilePath")
    def local_file_path(self) -> str:
        """
        The cache disk inside the device name.
        """
        return pulumi.get(self, "local_file_path")

    @property
    @pulumi.getter(name="renewUrl")
    def renew_url(self) -> str:
        """
        A renewal link of the cache disk.
        """
        return pulumi.get(self, "renew_url")

    @property
    @pulumi.getter
    def status(self) -> int:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class GetGatewayFileSharesShareResult(dict):
    def __init__(__self__, *,
                 access_based_enumeration: bool,
                 address: str,
                 backend_limit: int,
                 browsable: bool,
                 bucket_infos: str,
                 buckets_stub: bool,
                 bypass_cache_read: bool,
                 cache_mode: str,
                 client_side_cmk: str,
                 client_side_encryption: bool,
                 direct_io: bool,
                 disk_id: str,
                 disk_type: str,
                 download_limit: int,
                 enabled: bool,
                 express_sync_id: str,
                 fast_reclaim: bool,
                 fe_limit: int,
                 file_num_limit: str,
                 fs_size_limit: str,
                 gateway_file_share_name: str,
                 gateway_id: str,
                 id: str,
                 ignore_delete: bool,
                 in_place: bool,
                 in_rate: str,
                 index_id: str,
                 kms_rotate_period: int,
                 lag_period: str,
                 local_path: str,
                 mns_health: str,
                 nfs_v4_optimization: bool,
                 obsolete_buckets: str,
                 oss_bucket_name: str,
                 oss_bucket_ssl: bool,
                 oss_endpoint: str,
                 oss_health: str,
                 oss_used: str,
                 out_rate: str,
                 partial_sync_paths: str,
                 path_prefix: str,
                 polling_interval: int,
                 protocol: str,
                 remaining_meta_space: str,
                 remote_sync: bool,
                 remote_sync_download: bool,
                 ro_client_list: str,
                 ro_user_list: str,
                 rw_client_list: str,
                 rw_user_list: str,
                 server_side_cmk: str,
                 server_side_encryption: bool,
                 size: str,
                 squash: str,
                 state: str,
                 support_archive: bool,
                 sync_progress: int,
                 total_download: str,
                 total_upload: str,
                 transfer_acceleration: bool,
                 used: str,
                 windows_acl: bool):
        """
        :param bool access_based_enumeration: The set up gateway file share Server Message Block (SMB) protocol, whether to enable Windows ABE, the prime minister, need windowsAcl parameter is set to true in the entry into force of. Default value: `false`. **NOTE:** Gateway version >= 1.0.45 above support.
        :param str address: Share the private IP address of the RDS instance.
        :param int backend_limit: The set up gateway file share Max upload speed. Unit: `MB/s`, `0` means unlimited. Value range: `0` ~ `1280`. Default value: `0`. **NOTE:** at the same time if you have to limit the maximum write speed, maximum upload speed is no less than the maximum write speed.
        :param bool browsable: The set up gateway file share Server Message Block (SMB) protocol whether browsable (that is, in the network neighborhood of whether you can find). The parameters in the NFS protocol not valid under. Default value: `true`.
        :param str bucket_infos: Multi-Bucket information.
        :param bool buckets_stub: Whether there are multiple buckets.
        :param bool bypass_cache_read: Direct reading OSS of the gateway file share.
        :param str cache_mode: The cache mode of the gateway file share. Value range: Cache: cached mode. Sync: replication mode are available.
        :param str client_side_cmk: File share is enabled to client-side encryption, the encryption by the use of the KMS key. **NOTE:** note: This KMS key must be the gateway and is in the same Region.
        :param bool client_side_encryption: Whether to enabled to client-side encryption of the gateway file share. Default value: `false`. **NOTE:** need to contact us open whitelist before you can the settings, and only supports enhanced more than online gateway, at the same time, server-side encryption and to client-side encryption can not simultaneously configuration.
        :param bool direct_io: Whether directio (direct I/O data transfer) is enabled for file share. Default: `false`.
        :param str disk_id: The ID of the disk.
        :param str disk_type: The cache disk type. Valid values: `cloud_efficiency`: Ultra cloud disk. `cloud_ssd`:SSD cloud disk.
        :param int download_limit: The set up gateway file share maximum download speed. Unit: `MB/s`. `0` means unlimited. Value range: `0` ~ `1280`. **NOTE:** only in copy mode and enable download file data can be set. only when the shared opens the reverse synchronization or acceded to by the speed synchronization Group when, this parameter will not take effect. Gateway version >= 1.3.0 above support.
        :param bool enabled: Shared whether the changes take effect.
        :param str express_sync_id: Speed synchronization group ID.
        :param bool fast_reclaim: The set up gateway file share whether to enable Upload optimization, which is suitable for data pure backup migration scenarios. Default value: `false`. **NOTE:** Gateway version >= 1.0.39 above support.
        :param int fe_limit: The set up gateway file share and the maximum write speed. Unit: `MB/s`, `0` means unlimited. Value range: `0` ~ `1280`. Default value: `0`.
        :param str file_num_limit: Supported by the file system file number.
        :param str fs_size_limit: File system capacity. Unit: `B`.
        :param str gateway_file_share_name: The name of the file share. Length from `1` to `255` characters can contain lowercase letters, digits, (.), (_) Or (-), at the same time, must start with a lowercase letter.
        :param str gateway_id: The ID of the gateway.
        :param str id: The ID of the Gateway File Share.
        :param bool ignore_delete: Whether to ignore deleted of the gateway file share. After the opening of the Gateway side delete file or delete cloud (OSS) corresponding to the file. Default value: `false`. **NOTE:** Gateway version >= 1.0.40 above support.
        :param bool in_place: Whether debris optimization of the gateway file share. Default value: `false`.
        :param str in_rate: Cache growth. Unit: `B/s`.
        :param str index_id: The ID of the file share.
        :param int kms_rotate_period: File share is enabled to client-side encryption, key rotation period of time. Seconds. 0 represents no rotation. Rotation of the value range: `3600` ~ `86400`. Default value: `0`.
        :param str lag_period: The synchronization delay, I.e. gateway local cache sync to Alibaba Cloud Object Storage Service (oss) of the delay time. Unit: `Seconds`. Value range: `5` ~ `120`. Default value: `5`. **NOTE:** Gateway version >= 1.0.40 above support.
        :param str local_path: The cache disk inside the device name.
        :param str mns_health: The messages from the queue health types. Valid values: `TopicAndQueueFailure`: A Message Queuing message theme can be accessed during the black hole period. `TopicFailure`: a message theme can be accessed during the black hole period. `MNSFullSyncInit`: full synchronization wait. `MNSFullSyncing`: full synchronization in progress. `QueueFailure`: a message queue can be accessed during the black hole period. `MNSNotEnabled`: Top speed synchronization is not enabled. `MNSHealthy`: sync fine.
        :param bool nfs_v4_optimization: The set up gateway file share NFS protocol, whether to enable NFS v4 optimization improve Mount Upload efficiency. Default value: `false`. **NOTE:** turns on after I will not support NFS v3 mount the filesystem on a. Gateway version >= 1.2.0 above support.
        :param str obsolete_buckets: Multi-Bucket, removing the Bucket.
        :param str oss_bucket_name: The name of the Bucket.
        :param bool oss_bucket_ssl: Whether they are using SSL connect to OSS Bucket.
        :param str oss_endpoint: The set up gateway file share corresponds to the Object Storage SERVICE (OSS), Bucket Endpoint. **NOTE:** distinguish between intranet and internet Endpoint. We recommend that if the OSS Bucket and the gateway is in the same Region is use the RDS intranet IP Endpoint:oss-cn-hangzhou-internal.aliyuncs.com.
        :param str oss_health: The OSS Bucket of type. Valid values: `BucketHealthy`: OSS connectivity. `BucketAccessDenied`: OBJECT STORAGE Service (OSS) access to an exception. `BucketMiscFailure`: OBJECT STORAGE Service (OSS) access to additional exception. `BucketNetworkFailure`: OBJECT STORAGE Service (OSS) access network an exception. `BucketNotExist`: OSS Bucket does not exist. `Nothing returns`: We may not have ever known existed.
        :param str oss_used: For a cloud-based data is. Unit: `B`.
        :param str out_rate: Upload speed. Unit: `B/s`.
        :param str partial_sync_paths: In part mode, the directory path group JSON format.
        :param str path_prefix: The prefix of the OSS.
        :param int polling_interval: The reverse synchronization time intervals of the gateway file share. Value range: `15` ~ `36000`. **NOTE:** in copy mode + reverse synchronization is enabled Download file data, value range: `3600` ~ `36000`.
        :param str protocol: Share types. Valid values: `SMB`, `NFS`.
        :param str remaining_meta_space: You can use the metadata space. Unit: `B`.
        :param bool remote_sync: Whether to enable reverse synchronization of the gateway file share. Default value: `false`.
        :param bool remote_sync_download: Copy mode, whether to download the file data. Default value: `false`. **NOTE:** only when the shared opens the reverse synchronization or acceded to by the speed synchronization group, this parameter will not take effect.
        :param str ro_client_list: The read-only client list. When Protocol NFS is returned when the status is.
        :param str ro_user_list: The read-only client list. When Protocol for Server Message Block (SMB) to go back to.
        :param str rw_client_list: Read and write the client list. When Protocol NFS is returned when the status is.
        :param str rw_user_list: Read-write user list. When Protocol for Server Message Block (SMB) to go back to.
        :param str server_side_cmk: File share is enabled server-side encryption, encryption used by the KMS key.
        :param bool server_side_encryption: If the OSS Bucket side encryption.
        :param str size: The caching capacity. Unit: `B`.
        :param str squash: The set up gateway file share NFS protocol user mapping. Valid values: `none`, `root_squash`, `all_squash`, `all_anonymous`. Default value: `none`.
        :param str state: File synchronization types. Valid values: `clean`, `dirty`. `clean`: synchronization is complete. `dirty`: synchronization has not been completed.
        :param bool support_archive: Whether to support the archive transparent read.
        :param int sync_progress: Full synchronization progress. When the share has been added for a synchronization group, the return parameters are valid, that shared full synchronization progress (0~100). `-2`: indicates that share the Gateway version does not support this feature. `-1`: the share does not occur full synchronization.
        :param str total_download: The OSS Bucket to the Gateway total downloads. Unit: `B`.
        :param str total_upload: The OSS Bucket to the Gateway total Upload amount. Unit: `B`.
        :param bool transfer_acceleration: The set up gateway file share whether to enable transmission acceleration needs corresponding OSS Bucket enabled transport acceleration. **NOTE:** Gateway version >= 1.3.0 above support.
        :param str used: Used cache. Unit: `B`.
        :param bool windows_acl: The set up gateway file share Server Message Block (SMB) protocol, whether to enable by Windows access list (requires AD domain) the permissions control. Default value: `false`. **NOTE:** Gateway version >= 1.0.45 above support.
        """
        pulumi.set(__self__, "access_based_enumeration", access_based_enumeration)
        pulumi.set(__self__, "address", address)
        pulumi.set(__self__, "backend_limit", backend_limit)
        pulumi.set(__self__, "browsable", browsable)
        pulumi.set(__self__, "bucket_infos", bucket_infos)
        pulumi.set(__self__, "buckets_stub", buckets_stub)
        pulumi.set(__self__, "bypass_cache_read", bypass_cache_read)
        pulumi.set(__self__, "cache_mode", cache_mode)
        pulumi.set(__self__, "client_side_cmk", client_side_cmk)
        pulumi.set(__self__, "client_side_encryption", client_side_encryption)
        pulumi.set(__self__, "direct_io", direct_io)
        pulumi.set(__self__, "disk_id", disk_id)
        pulumi.set(__self__, "disk_type", disk_type)
        pulumi.set(__self__, "download_limit", download_limit)
        pulumi.set(__self__, "enabled", enabled)
        pulumi.set(__self__, "express_sync_id", express_sync_id)
        pulumi.set(__self__, "fast_reclaim", fast_reclaim)
        pulumi.set(__self__, "fe_limit", fe_limit)
        pulumi.set(__self__, "file_num_limit", file_num_limit)
        pulumi.set(__self__, "fs_size_limit", fs_size_limit)
        pulumi.set(__self__, "gateway_file_share_name", gateway_file_share_name)
        pulumi.set(__self__, "gateway_id", gateway_id)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "ignore_delete", ignore_delete)
        pulumi.set(__self__, "in_place", in_place)
        pulumi.set(__self__, "in_rate", in_rate)
        pulumi.set(__self__, "index_id", index_id)
        pulumi.set(__self__, "kms_rotate_period", kms_rotate_period)
        pulumi.set(__self__, "lag_period", lag_period)
        pulumi.set(__self__, "local_path", local_path)
        pulumi.set(__self__, "mns_health", mns_health)
        pulumi.set(__self__, "nfs_v4_optimization", nfs_v4_optimization)
        pulumi.set(__self__, "obsolete_buckets", obsolete_buckets)
        pulumi.set(__self__, "oss_bucket_name", oss_bucket_name)
        pulumi.set(__self__, "oss_bucket_ssl", oss_bucket_ssl)
        pulumi.set(__self__, "oss_endpoint", oss_endpoint)
        pulumi.set(__self__, "oss_health", oss_health)
        pulumi.set(__self__, "oss_used", oss_used)
        pulumi.set(__self__, "out_rate", out_rate)
        pulumi.set(__self__, "partial_sync_paths", partial_sync_paths)
        pulumi.set(__self__, "path_prefix", path_prefix)
        pulumi.set(__self__, "polling_interval", polling_interval)
        pulumi.set(__self__, "protocol", protocol)
        pulumi.set(__self__, "remaining_meta_space", remaining_meta_space)
        pulumi.set(__self__, "remote_sync", remote_sync)
        pulumi.set(__self__, "remote_sync_download", remote_sync_download)
        pulumi.set(__self__, "ro_client_list", ro_client_list)
        pulumi.set(__self__, "ro_user_list", ro_user_list)
        pulumi.set(__self__, "rw_client_list", rw_client_list)
        pulumi.set(__self__, "rw_user_list", rw_user_list)
        pulumi.set(__self__, "server_side_cmk", server_side_cmk)
        pulumi.set(__self__, "server_side_encryption", server_side_encryption)
        pulumi.set(__self__, "size", size)
        pulumi.set(__self__, "squash", squash)
        pulumi.set(__self__, "state", state)
        pulumi.set(__self__, "support_archive", support_archive)
        pulumi.set(__self__, "sync_progress", sync_progress)
        pulumi.set(__self__, "total_download", total_download)
        pulumi.set(__self__, "total_upload", total_upload)
        pulumi.set(__self__, "transfer_acceleration", transfer_acceleration)
        pulumi.set(__self__, "used", used)
        pulumi.set(__self__, "windows_acl", windows_acl)

    @property
    @pulumi.getter(name="accessBasedEnumeration")
    def access_based_enumeration(self) -> bool:
        """
        The set up gateway file share Server Message Block (SMB) protocol, whether to enable Windows ABE, the prime minister, need windowsAcl parameter is set to true in the entry into force of. Default value: `false`. **NOTE:** Gateway version >= 1.0.45 above support.
        """
        return pulumi.get(self, "access_based_enumeration")

    @property
    @pulumi.getter
    def address(self) -> str:
        """
        Share the private IP address of the RDS instance.
        """
        return pulumi.get(self, "address")

    @property
    @pulumi.getter(name="backendLimit")
    def backend_limit(self) -> int:
        """
        The set up gateway file share Max upload speed. Unit: `MB/s`, `0` means unlimited. Value range: `0` ~ `1280`. Default value: `0`. **NOTE:** at the same time if you have to limit the maximum write speed, maximum upload speed is no less than the maximum write speed.
        """
        return pulumi.get(self, "backend_limit")

    @property
    @pulumi.getter
    def browsable(self) -> bool:
        """
        The set up gateway file share Server Message Block (SMB) protocol whether browsable (that is, in the network neighborhood of whether you can find). The parameters in the NFS protocol not valid under. Default value: `true`.
        """
        return pulumi.get(self, "browsable")

    @property
    @pulumi.getter(name="bucketInfos")
    def bucket_infos(self) -> str:
        """
        Multi-Bucket information.
        """
        return pulumi.get(self, "bucket_infos")

    @property
    @pulumi.getter(name="bucketsStub")
    def buckets_stub(self) -> bool:
        """
        Whether there are multiple buckets.
        """
        return pulumi.get(self, "buckets_stub")

    @property
    @pulumi.getter(name="bypassCacheRead")
    def bypass_cache_read(self) -> bool:
        """
        Direct reading OSS of the gateway file share.
        """
        return pulumi.get(self, "bypass_cache_read")

    @property
    @pulumi.getter(name="cacheMode")
    def cache_mode(self) -> str:
        """
        The cache mode of the gateway file share. Value range: Cache: cached mode. Sync: replication mode are available.
        """
        return pulumi.get(self, "cache_mode")

    @property
    @pulumi.getter(name="clientSideCmk")
    def client_side_cmk(self) -> str:
        """
        File share is enabled to client-side encryption, the encryption by the use of the KMS key. **NOTE:** note: This KMS key must be the gateway and is in the same Region.
        """
        return pulumi.get(self, "client_side_cmk")

    @property
    @pulumi.getter(name="clientSideEncryption")
    def client_side_encryption(self) -> bool:
        """
        Whether to enabled to client-side encryption of the gateway file share. Default value: `false`. **NOTE:** need to contact us open whitelist before you can the settings, and only supports enhanced more than online gateway, at the same time, server-side encryption and to client-side encryption can not simultaneously configuration.
        """
        return pulumi.get(self, "client_side_encryption")

    @property
    @pulumi.getter(name="directIo")
    def direct_io(self) -> bool:
        """
        Whether directio (direct I/O data transfer) is enabled for file share. Default: `false`.
        """
        return pulumi.get(self, "direct_io")

    @property
    @pulumi.getter(name="diskId")
    def disk_id(self) -> str:
        """
        The ID of the disk.
        """
        return pulumi.get(self, "disk_id")

    @property
    @pulumi.getter(name="diskType")
    def disk_type(self) -> str:
        """
        The cache disk type. Valid values: `cloud_efficiency`: Ultra cloud disk. `cloud_ssd`:SSD cloud disk.
        """
        return pulumi.get(self, "disk_type")

    @property
    @pulumi.getter(name="downloadLimit")
    def download_limit(self) -> int:
        """
        The set up gateway file share maximum download speed. Unit: `MB/s`. `0` means unlimited. Value range: `0` ~ `1280`. **NOTE:** only in copy mode and enable download file data can be set. only when the shared opens the reverse synchronization or acceded to by the speed synchronization Group when, this parameter will not take effect. Gateway version >= 1.3.0 above support.
        """
        return pulumi.get(self, "download_limit")

    @property
    @pulumi.getter
    def enabled(self) -> bool:
        """
        Shared whether the changes take effect.
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter(name="expressSyncId")
    def express_sync_id(self) -> str:
        """
        Speed synchronization group ID.
        """
        return pulumi.get(self, "express_sync_id")

    @property
    @pulumi.getter(name="fastReclaim")
    def fast_reclaim(self) -> bool:
        """
        The set up gateway file share whether to enable Upload optimization, which is suitable for data pure backup migration scenarios. Default value: `false`. **NOTE:** Gateway version >= 1.0.39 above support.
        """
        return pulumi.get(self, "fast_reclaim")

    @property
    @pulumi.getter(name="feLimit")
    def fe_limit(self) -> int:
        """
        The set up gateway file share and the maximum write speed. Unit: `MB/s`, `0` means unlimited. Value range: `0` ~ `1280`. Default value: `0`.
        """
        return pulumi.get(self, "fe_limit")

    @property
    @pulumi.getter(name="fileNumLimit")
    def file_num_limit(self) -> str:
        """
        Supported by the file system file number.
        """
        return pulumi.get(self, "file_num_limit")

    @property
    @pulumi.getter(name="fsSizeLimit")
    def fs_size_limit(self) -> str:
        """
        File system capacity. Unit: `B`.
        """
        return pulumi.get(self, "fs_size_limit")

    @property
    @pulumi.getter(name="gatewayFileShareName")
    def gateway_file_share_name(self) -> str:
        """
        The name of the file share. Length from `1` to `255` characters can contain lowercase letters, digits, (.), (_) Or (-), at the same time, must start with a lowercase letter.
        """
        return pulumi.get(self, "gateway_file_share_name")

    @property
    @pulumi.getter(name="gatewayId")
    def gateway_id(self) -> str:
        """
        The ID of the gateway.
        """
        return pulumi.get(self, "gateway_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Gateway File Share.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ignoreDelete")
    def ignore_delete(self) -> bool:
        """
        Whether to ignore deleted of the gateway file share. After the opening of the Gateway side delete file or delete cloud (OSS) corresponding to the file. Default value: `false`. **NOTE:** Gateway version >= 1.0.40 above support.
        """
        return pulumi.get(self, "ignore_delete")

    @property
    @pulumi.getter(name="inPlace")
    def in_place(self) -> bool:
        """
        Whether debris optimization of the gateway file share. Default value: `false`.
        """
        return pulumi.get(self, "in_place")

    @property
    @pulumi.getter(name="inRate")
    def in_rate(self) -> str:
        """
        Cache growth. Unit: `B/s`.
        """
        return pulumi.get(self, "in_rate")

    @property
    @pulumi.getter(name="indexId")
    def index_id(self) -> str:
        """
        The ID of the file share.
        """
        return pulumi.get(self, "index_id")

    @property
    @pulumi.getter(name="kmsRotatePeriod")
    def kms_rotate_period(self) -> int:
        """
        File share is enabled to client-side encryption, key rotation period of time. Seconds. 0 represents no rotation. Rotation of the value range: `3600` ~ `86400`. Default value: `0`.
        """
        return pulumi.get(self, "kms_rotate_period")

    @property
    @pulumi.getter(name="lagPeriod")
    def lag_period(self) -> str:
        """
        The synchronization delay, I.e. gateway local cache sync to Alibaba Cloud Object Storage Service (oss) of the delay time. Unit: `Seconds`. Value range: `5` ~ `120`. Default value: `5`. **NOTE:** Gateway version >= 1.0.40 above support.
        """
        return pulumi.get(self, "lag_period")

    @property
    @pulumi.getter(name="localPath")
    def local_path(self) -> str:
        """
        The cache disk inside the device name.
        """
        return pulumi.get(self, "local_path")

    @property
    @pulumi.getter(name="mnsHealth")
    def mns_health(self) -> str:
        """
        The messages from the queue health types. Valid values: `TopicAndQueueFailure`: A Message Queuing message theme can be accessed during the black hole period. `TopicFailure`: a message theme can be accessed during the black hole period. `MNSFullSyncInit`: full synchronization wait. `MNSFullSyncing`: full synchronization in progress. `QueueFailure`: a message queue can be accessed during the black hole period. `MNSNotEnabled`: Top speed synchronization is not enabled. `MNSHealthy`: sync fine.
        """
        return pulumi.get(self, "mns_health")

    @property
    @pulumi.getter(name="nfsV4Optimization")
    def nfs_v4_optimization(self) -> bool:
        """
        The set up gateway file share NFS protocol, whether to enable NFS v4 optimization improve Mount Upload efficiency. Default value: `false`. **NOTE:** turns on after I will not support NFS v3 mount the filesystem on a. Gateway version >= 1.2.0 above support.
        """
        return pulumi.get(self, "nfs_v4_optimization")

    @property
    @pulumi.getter(name="obsoleteBuckets")
    def obsolete_buckets(self) -> str:
        """
        Multi-Bucket, removing the Bucket.
        """
        return pulumi.get(self, "obsolete_buckets")

    @property
    @pulumi.getter(name="ossBucketName")
    def oss_bucket_name(self) -> str:
        """
        The name of the Bucket.
        """
        return pulumi.get(self, "oss_bucket_name")

    @property
    @pulumi.getter(name="ossBucketSsl")
    def oss_bucket_ssl(self) -> bool:
        """
        Whether they are using SSL connect to OSS Bucket.
        """
        return pulumi.get(self, "oss_bucket_ssl")

    @property
    @pulumi.getter(name="ossEndpoint")
    def oss_endpoint(self) -> str:
        """
        The set up gateway file share corresponds to the Object Storage SERVICE (OSS), Bucket Endpoint. **NOTE:** distinguish between intranet and internet Endpoint. We recommend that if the OSS Bucket and the gateway is in the same Region is use the RDS intranet IP Endpoint:oss-cn-hangzhou-internal.aliyuncs.com.
        """
        return pulumi.get(self, "oss_endpoint")

    @property
    @pulumi.getter(name="ossHealth")
    def oss_health(self) -> str:
        """
        The OSS Bucket of type. Valid values: `BucketHealthy`: OSS connectivity. `BucketAccessDenied`: OBJECT STORAGE Service (OSS) access to an exception. `BucketMiscFailure`: OBJECT STORAGE Service (OSS) access to additional exception. `BucketNetworkFailure`: OBJECT STORAGE Service (OSS) access network an exception. `BucketNotExist`: OSS Bucket does not exist. `Nothing returns`: We may not have ever known existed.
        """
        return pulumi.get(self, "oss_health")

    @property
    @pulumi.getter(name="ossUsed")
    def oss_used(self) -> str:
        """
        For a cloud-based data is. Unit: `B`.
        """
        return pulumi.get(self, "oss_used")

    @property
    @pulumi.getter(name="outRate")
    def out_rate(self) -> str:
        """
        Upload speed. Unit: `B/s`.
        """
        return pulumi.get(self, "out_rate")

    @property
    @pulumi.getter(name="partialSyncPaths")
    def partial_sync_paths(self) -> str:
        """
        In part mode, the directory path group JSON format.
        """
        return pulumi.get(self, "partial_sync_paths")

    @property
    @pulumi.getter(name="pathPrefix")
    def path_prefix(self) -> str:
        """
        The prefix of the OSS.
        """
        return pulumi.get(self, "path_prefix")

    @property
    @pulumi.getter(name="pollingInterval")
    def polling_interval(self) -> int:
        """
        The reverse synchronization time intervals of the gateway file share. Value range: `15` ~ `36000`. **NOTE:** in copy mode + reverse synchronization is enabled Download file data, value range: `3600` ~ `36000`.
        """
        return pulumi.get(self, "polling_interval")

    @property
    @pulumi.getter
    def protocol(self) -> str:
        """
        Share types. Valid values: `SMB`, `NFS`.
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter(name="remainingMetaSpace")
    def remaining_meta_space(self) -> str:
        """
        You can use the metadata space. Unit: `B`.
        """
        return pulumi.get(self, "remaining_meta_space")

    @property
    @pulumi.getter(name="remoteSync")
    def remote_sync(self) -> bool:
        """
        Whether to enable reverse synchronization of the gateway file share. Default value: `false`.
        """
        return pulumi.get(self, "remote_sync")

    @property
    @pulumi.getter(name="remoteSyncDownload")
    def remote_sync_download(self) -> bool:
        """
        Copy mode, whether to download the file data. Default value: `false`. **NOTE:** only when the shared opens the reverse synchronization or acceded to by the speed synchronization group, this parameter will not take effect.
        """
        return pulumi.get(self, "remote_sync_download")

    @property
    @pulumi.getter(name="roClientList")
    def ro_client_list(self) -> str:
        """
        The read-only client list. When Protocol NFS is returned when the status is.
        """
        return pulumi.get(self, "ro_client_list")

    @property
    @pulumi.getter(name="roUserList")
    def ro_user_list(self) -> str:
        """
        The read-only client list. When Protocol for Server Message Block (SMB) to go back to.
        """
        return pulumi.get(self, "ro_user_list")

    @property
    @pulumi.getter(name="rwClientList")
    def rw_client_list(self) -> str:
        """
        Read and write the client list. When Protocol NFS is returned when the status is.
        """
        return pulumi.get(self, "rw_client_list")

    @property
    @pulumi.getter(name="rwUserList")
    def rw_user_list(self) -> str:
        """
        Read-write user list. When Protocol for Server Message Block (SMB) to go back to.
        """
        return pulumi.get(self, "rw_user_list")

    @property
    @pulumi.getter(name="serverSideCmk")
    def server_side_cmk(self) -> str:
        """
        File share is enabled server-side encryption, encryption used by the KMS key.
        """
        return pulumi.get(self, "server_side_cmk")

    @property
    @pulumi.getter(name="serverSideEncryption")
    def server_side_encryption(self) -> bool:
        """
        If the OSS Bucket side encryption.
        """
        return pulumi.get(self, "server_side_encryption")

    @property
    @pulumi.getter
    def size(self) -> str:
        """
        The caching capacity. Unit: `B`.
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter
    def squash(self) -> str:
        """
        The set up gateway file share NFS protocol user mapping. Valid values: `none`, `root_squash`, `all_squash`, `all_anonymous`. Default value: `none`.
        """
        return pulumi.get(self, "squash")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        File synchronization types. Valid values: `clean`, `dirty`. `clean`: synchronization is complete. `dirty`: synchronization has not been completed.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="supportArchive")
    def support_archive(self) -> bool:
        """
        Whether to support the archive transparent read.
        """
        return pulumi.get(self, "support_archive")

    @property
    @pulumi.getter(name="syncProgress")
    def sync_progress(self) -> int:
        """
        Full synchronization progress. When the share has been added for a synchronization group, the return parameters are valid, that shared full synchronization progress (0~100). `-2`: indicates that share the Gateway version does not support this feature. `-1`: the share does not occur full synchronization.
        """
        return pulumi.get(self, "sync_progress")

    @property
    @pulumi.getter(name="totalDownload")
    def total_download(self) -> str:
        """
        The OSS Bucket to the Gateway total downloads. Unit: `B`.
        """
        return pulumi.get(self, "total_download")

    @property
    @pulumi.getter(name="totalUpload")
    def total_upload(self) -> str:
        """
        The OSS Bucket to the Gateway total Upload amount. Unit: `B`.
        """
        return pulumi.get(self, "total_upload")

    @property
    @pulumi.getter(name="transferAcceleration")
    def transfer_acceleration(self) -> bool:
        """
        The set up gateway file share whether to enable transmission acceleration needs corresponding OSS Bucket enabled transport acceleration. **NOTE:** Gateway version >= 1.3.0 above support.
        """
        return pulumi.get(self, "transfer_acceleration")

    @property
    @pulumi.getter
    def used(self) -> str:
        """
        Used cache. Unit: `B`.
        """
        return pulumi.get(self, "used")

    @property
    @pulumi.getter(name="windowsAcl")
    def windows_acl(self) -> bool:
        """
        The set up gateway file share Server Message Block (SMB) protocol, whether to enable by Windows access list (requires AD domain) the permissions control. Default value: `false`. **NOTE:** Gateway version >= 1.0.45 above support.
        """
        return pulumi.get(self, "windows_acl")


@pulumi.output_type
class GetGatewaySmbUsersUserResult(dict):
    def __init__(__self__, *,
                 gateway_id: str,
                 id: str,
                 username: str):
        """
        :param str gateway_id: The Gateway ID.
        :param str id: The ID of the Gateway SMB User.
        :param str username: The username of the Gateway SMB User.
        """
        pulumi.set(__self__, "gateway_id", gateway_id)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter(name="gatewayId")
    def gateway_id(self) -> str:
        """
        The Gateway ID.
        """
        return pulumi.get(self, "gateway_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Gateway SMB User.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def username(self) -> str:
        """
        The username of the Gateway SMB User.
        """
        return pulumi.get(self, "username")


@pulumi.output_type
class GetGatewaysGatewayResult(dict):
    def __init__(__self__, *,
                 activated_time: str,
                 buy_url: str,
                 category: str,
                 create_time: str,
                 description: str,
                 ecs_instance_id: str,
                 expire_status: int,
                 expired_time: str,
                 gateway_class: str,
                 gateway_id: str,
                 gateway_name: str,
                 gateway_version: str,
                 id: str,
                 inner_ip: str,
                 ip: str,
                 is_release_after_expiration: bool,
                 location: str,
                 payment_type: str,
                 public_network_bandwidth: int,
                 renew_url: str,
                 status: str,
                 storage_bundle_id: str,
                 task_id: str,
                 type: str,
                 vpc_id: str,
                 vswitch_id: str):
        """
        :param str activated_time: gateway .
        :param str category: gateway category.
        :param str create_time: gateway created timestamp in second format.
        :param str description: gateway description.
        :param str ecs_instance_id: gateway ecs instance id.
        :param int expire_status: gateway expiration status.
        :param str expired_time: gateway expiration timestamp in second format.
        :param str gateway_class: gateway class.
        :param str gateway_id: gateway id.
        :param str gateway_name: gateway name.
        :param str gateway_version: gateway version.
        :param str id: The ID of the Gateway.
        :param str inner_ip: gateway service ip.
        :param str ip: gateway public ip.
        :param bool is_release_after_expiration: whether subscription gateway is released after expiration or not.
        :param str location: gateway location.
        :param str payment_type: gateway payment type. The Payment type of gateway. The valid value: `PayAsYouGo`, `Subscription`.
        :param int public_network_bandwidth: gateway public network bandwidth.
        :param str status: gateway status.
        :param str storage_bundle_id: storage bundle id.
        :param str task_id: gateway task id.
        :param str type: gateway type.
        :param str vpc_id: gateway vpc id.
        :param str vswitch_id: The vswitch id.
        """
        pulumi.set(__self__, "activated_time", activated_time)
        pulumi.set(__self__, "buy_url", buy_url)
        pulumi.set(__self__, "category", category)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "ecs_instance_id", ecs_instance_id)
        pulumi.set(__self__, "expire_status", expire_status)
        pulumi.set(__self__, "expired_time", expired_time)
        pulumi.set(__self__, "gateway_class", gateway_class)
        pulumi.set(__self__, "gateway_id", gateway_id)
        pulumi.set(__self__, "gateway_name", gateway_name)
        pulumi.set(__self__, "gateway_version", gateway_version)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "inner_ip", inner_ip)
        pulumi.set(__self__, "ip", ip)
        pulumi.set(__self__, "is_release_after_expiration", is_release_after_expiration)
        pulumi.set(__self__, "location", location)
        pulumi.set(__self__, "payment_type", payment_type)
        pulumi.set(__self__, "public_network_bandwidth", public_network_bandwidth)
        pulumi.set(__self__, "renew_url", renew_url)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "storage_bundle_id", storage_bundle_id)
        pulumi.set(__self__, "task_id", task_id)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "vpc_id", vpc_id)
        pulumi.set(__self__, "vswitch_id", vswitch_id)

    @property
    @pulumi.getter(name="activatedTime")
    def activated_time(self) -> str:
        """
        gateway .
        """
        return pulumi.get(self, "activated_time")

    @property
    @pulumi.getter(name="buyUrl")
    def buy_url(self) -> str:
        return pulumi.get(self, "buy_url")

    @property
    @pulumi.getter
    def category(self) -> str:
        """
        gateway category.
        """
        return pulumi.get(self, "category")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        gateway created timestamp in second format.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        gateway description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="ecsInstanceId")
    def ecs_instance_id(self) -> str:
        """
        gateway ecs instance id.
        """
        return pulumi.get(self, "ecs_instance_id")

    @property
    @pulumi.getter(name="expireStatus")
    def expire_status(self) -> int:
        """
        gateway expiration status.
        """
        return pulumi.get(self, "expire_status")

    @property
    @pulumi.getter(name="expiredTime")
    def expired_time(self) -> str:
        """
        gateway expiration timestamp in second format.
        """
        return pulumi.get(self, "expired_time")

    @property
    @pulumi.getter(name="gatewayClass")
    def gateway_class(self) -> str:
        """
        gateway class.
        """
        return pulumi.get(self, "gateway_class")

    @property
    @pulumi.getter(name="gatewayId")
    def gateway_id(self) -> str:
        """
        gateway id.
        """
        return pulumi.get(self, "gateway_id")

    @property
    @pulumi.getter(name="gatewayName")
    def gateway_name(self) -> str:
        """
        gateway name.
        """
        return pulumi.get(self, "gateway_name")

    @property
    @pulumi.getter(name="gatewayVersion")
    def gateway_version(self) -> str:
        """
        gateway version.
        """
        return pulumi.get(self, "gateway_version")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Gateway.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="innerIp")
    def inner_ip(self) -> str:
        """
        gateway service ip.
        """
        return pulumi.get(self, "inner_ip")

    @property
    @pulumi.getter
    def ip(self) -> str:
        """
        gateway public ip.
        """
        return pulumi.get(self, "ip")

    @property
    @pulumi.getter(name="isReleaseAfterExpiration")
    def is_release_after_expiration(self) -> bool:
        """
        whether subscription gateway is released after expiration or not.
        """
        return pulumi.get(self, "is_release_after_expiration")

    @property
    @pulumi.getter
    def location(self) -> str:
        """
        gateway location.
        """
        return pulumi.get(self, "location")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> str:
        """
        gateway payment type. The Payment type of gateway. The valid value: `PayAsYouGo`, `Subscription`.
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter(name="publicNetworkBandwidth")
    def public_network_bandwidth(self) -> int:
        """
        gateway public network bandwidth.
        """
        return pulumi.get(self, "public_network_bandwidth")

    @property
    @pulumi.getter(name="renewUrl")
    def renew_url(self) -> str:
        return pulumi.get(self, "renew_url")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        gateway status.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="storageBundleId")
    def storage_bundle_id(self) -> str:
        """
        storage bundle id.
        """
        return pulumi.get(self, "storage_bundle_id")

    @property
    @pulumi.getter(name="taskId")
    def task_id(self) -> str:
        """
        gateway task id.
        """
        return pulumi.get(self, "task_id")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        gateway type.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> str:
        """
        gateway vpc id.
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> str:
        """
        The vswitch id.
        """
        return pulumi.get(self, "vswitch_id")


@pulumi.output_type
class GetStocksStockResult(dict):
    def __init__(__self__, *,
                 available_gateway_classes: Sequence[str],
                 zone_id: str):
        """
        :param Sequence[str] available_gateway_classes: A list of available gateway class in this Zone ID.
        :param str zone_id: The Zone ID.
        """
        pulumi.set(__self__, "available_gateway_classes", available_gateway_classes)
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="availableGatewayClasses")
    def available_gateway_classes(self) -> Sequence[str]:
        """
        A list of available gateway class in this Zone ID.
        """
        return pulumi.get(self, "available_gateway_classes")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> str:
        """
        The Zone ID.
        """
        return pulumi.get(self, "zone_id")


@pulumi.output_type
class GetStorageBundlesBundleResult(dict):
    def __init__(__self__, *,
                 create_time: str,
                 description: str,
                 id: str,
                 location: str,
                 storage_bundle_id: str,
                 storage_bundle_name: str):
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "location", location)
        pulumi.set(__self__, "storage_bundle_id", storage_bundle_id)
        pulumi.set(__self__, "storage_bundle_name", storage_bundle_name)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> str:
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def location(self) -> str:
        return pulumi.get(self, "location")

    @property
    @pulumi.getter(name="storageBundleId")
    def storage_bundle_id(self) -> str:
        return pulumi.get(self, "storage_bundle_id")

    @property
    @pulumi.getter(name="storageBundleName")
    def storage_bundle_name(self) -> str:
        return pulumi.get(self, "storage_bundle_name")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'ClusterBootstrapActionArgs',
    'ClusterHostGroupArgs',
]

@pulumi.input_type
class ClusterBootstrapActionArgs:
    def __init__(__self__, *,
                 arg: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 path: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] arg: bootstrap action args, e.g. "--a=b".
        :param pulumi.Input[str] name: bootstrap action name.
        :param pulumi.Input[str] path: bootstrap action path, e.g. "oss://bucket/path".
        """
        if arg is not None:
            pulumi.set(__self__, "arg", arg)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if path is not None:
            pulumi.set(__self__, "path", path)

    @property
    @pulumi.getter
    def arg(self) -> Optional[pulumi.Input[str]]:
        """
        bootstrap action args, e.g. "--a=b".
        """
        return pulumi.get(self, "arg")

    @arg.setter
    def arg(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "arg", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        bootstrap action name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def path(self) -> Optional[pulumi.Input[str]]:
        """
        bootstrap action path, e.g. "oss://bucket/path".
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "path", value)


@pulumi.input_type
class ClusterHostGroupArgs:
    def __init__(__self__, *,
                 auto_renew: Optional[pulumi.Input[bool]] = None,
                 charge_type: Optional[pulumi.Input[str]] = None,
                 disk_capacity: Optional[pulumi.Input[str]] = None,
                 disk_count: Optional[pulumi.Input[str]] = None,
                 disk_type: Optional[pulumi.Input[str]] = None,
                 gpu_driver: Optional[pulumi.Input[str]] = None,
                 host_group_name: Optional[pulumi.Input[str]] = None,
                 host_group_type: Optional[pulumi.Input[str]] = None,
                 instance_list: Optional[pulumi.Input[str]] = None,
                 instance_type: Optional[pulumi.Input[str]] = None,
                 node_count: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 sys_disk_capacity: Optional[pulumi.Input[str]] = None,
                 sys_disk_type: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[bool] auto_renew: Auto renew for prepaid, true of false. Default is false.
        :param pulumi.Input[str] charge_type: Charge Type for this group of hosts: PostPaid or PrePaid. If this is not specified, charge type will follow global charge_type value.
        :param pulumi.Input[str] disk_capacity: Data disk capacity.
        :param pulumi.Input[str] disk_count: Data disk count.
        :param pulumi.Input[str] disk_type: Data disk type. Supported value: cloud,cloud_efficiency,cloud_ssd,local_disk,cloud_essd.
        :param pulumi.Input[str] host_group_name: host group name.
        :param pulumi.Input[str] host_group_type: host group type, supported value: MASTER, CORE or TASK, supported 'GATEWAY' available in 1.61.0+.
        :param pulumi.Input[str] instance_list: Instance list for cluster scale down. This value follows the json format, e.g. ["instance_id1","instance_id2"]. escape character for " is \".
        :param pulumi.Input[str] instance_type: Host Ecs instance type.
        :param pulumi.Input[str] node_count: Host number in this group.
        :param pulumi.Input[int] period: If charge type is PrePaid, this should be specified, unit is month. Supported value: 1、2、3、4、5、6、7、8、9、12、24、36.
        :param pulumi.Input[str] sys_disk_capacity: System disk capacity.
        :param pulumi.Input[str] sys_disk_type: System disk type. Supported value: cloud,cloud_efficiency,cloud_ssd,cloud_essd.
        """
        if auto_renew is not None:
            pulumi.set(__self__, "auto_renew", auto_renew)
        if charge_type is not None:
            pulumi.set(__self__, "charge_type", charge_type)
        if disk_capacity is not None:
            pulumi.set(__self__, "disk_capacity", disk_capacity)
        if disk_count is not None:
            pulumi.set(__self__, "disk_count", disk_count)
        if disk_type is not None:
            pulumi.set(__self__, "disk_type", disk_type)
        if gpu_driver is not None:
            pulumi.set(__self__, "gpu_driver", gpu_driver)
        if host_group_name is not None:
            pulumi.set(__self__, "host_group_name", host_group_name)
        if host_group_type is not None:
            pulumi.set(__self__, "host_group_type", host_group_type)
        if instance_list is not None:
            pulumi.set(__self__, "instance_list", instance_list)
        if instance_type is not None:
            pulumi.set(__self__, "instance_type", instance_type)
        if node_count is not None:
            pulumi.set(__self__, "node_count", node_count)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if sys_disk_capacity is not None:
            pulumi.set(__self__, "sys_disk_capacity", sys_disk_capacity)
        if sys_disk_type is not None:
            pulumi.set(__self__, "sys_disk_type", sys_disk_type)

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> Optional[pulumi.Input[bool]]:
        """
        Auto renew for prepaid, true of false. Default is false.
        """
        return pulumi.get(self, "auto_renew")

    @auto_renew.setter
    def auto_renew(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_renew", value)

    @property
    @pulumi.getter(name="chargeType")
    def charge_type(self) -> Optional[pulumi.Input[str]]:
        """
        Charge Type for this group of hosts: PostPaid or PrePaid. If this is not specified, charge type will follow global charge_type value.
        """
        return pulumi.get(self, "charge_type")

    @charge_type.setter
    def charge_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "charge_type", value)

    @property
    @pulumi.getter(name="diskCapacity")
    def disk_capacity(self) -> Optional[pulumi.Input[str]]:
        """
        Data disk capacity.
        """
        return pulumi.get(self, "disk_capacity")

    @disk_capacity.setter
    def disk_capacity(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "disk_capacity", value)

    @property
    @pulumi.getter(name="diskCount")
    def disk_count(self) -> Optional[pulumi.Input[str]]:
        """
        Data disk count.
        """
        return pulumi.get(self, "disk_count")

    @disk_count.setter
    def disk_count(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "disk_count", value)

    @property
    @pulumi.getter(name="diskType")
    def disk_type(self) -> Optional[pulumi.Input[str]]:
        """
        Data disk type. Supported value: cloud,cloud_efficiency,cloud_ssd,local_disk,cloud_essd.
        """
        return pulumi.get(self, "disk_type")

    @disk_type.setter
    def disk_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "disk_type", value)

    @property
    @pulumi.getter(name="gpuDriver")
    def gpu_driver(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "gpu_driver")

    @gpu_driver.setter
    def gpu_driver(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "gpu_driver", value)

    @property
    @pulumi.getter(name="hostGroupName")
    def host_group_name(self) -> Optional[pulumi.Input[str]]:
        """
        host group name.
        """
        return pulumi.get(self, "host_group_name")

    @host_group_name.setter
    def host_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "host_group_name", value)

    @property
    @pulumi.getter(name="hostGroupType")
    def host_group_type(self) -> Optional[pulumi.Input[str]]:
        """
        host group type, supported value: MASTER, CORE or TASK, supported 'GATEWAY' available in 1.61.0+.
        """
        return pulumi.get(self, "host_group_type")

    @host_group_type.setter
    def host_group_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "host_group_type", value)

    @property
    @pulumi.getter(name="instanceList")
    def instance_list(self) -> Optional[pulumi.Input[str]]:
        """
        Instance list for cluster scale down. This value follows the json format, e.g. ["instance_id1","instance_id2"]. escape character for " is \".
        """
        return pulumi.get(self, "instance_list")

    @instance_list.setter
    def instance_list(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_list", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[pulumi.Input[str]]:
        """
        Host Ecs instance type.
        """
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter(name="nodeCount")
    def node_count(self) -> Optional[pulumi.Input[str]]:
        """
        Host number in this group.
        """
        return pulumi.get(self, "node_count")

    @node_count.setter
    def node_count(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "node_count", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[int]]:
        """
        If charge type is PrePaid, this should be specified, unit is month. Supported value: 1、2、3、4、5、6、7、8、9、12、24、36.
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="sysDiskCapacity")
    def sys_disk_capacity(self) -> Optional[pulumi.Input[str]]:
        """
        System disk capacity.
        """
        return pulumi.get(self, "sys_disk_capacity")

    @sys_disk_capacity.setter
    def sys_disk_capacity(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sys_disk_capacity", value)

    @property
    @pulumi.getter(name="sysDiskType")
    def sys_disk_type(self) -> Optional[pulumi.Input[str]]:
        """
        System disk type. Supported value: cloud,cloud_efficiency,cloud_ssd,cloud_essd.
        """
        return pulumi.get(self, "sys_disk_type")

    @sys_disk_type.setter
    def sys_disk_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sys_disk_type", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['VbrHaArgs', 'VbrHa']

@pulumi.input_type
class VbrHaArgs:
    def __init__(__self__, *,
                 peer_vbr_id: pulumi.Input[str],
                 vbr_id: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None,
                 dry_run: Optional[pulumi.Input[bool]] = None,
                 vbr_ha_name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a VbrHa resource.
        :param pulumi.Input[str] peer_vbr_id: The ID of the other VBR in the VBR failover group.
        :param pulumi.Input[str] vbr_id: The ID of the VBR instance.
        :param pulumi.Input[str] description: The description of the VBR switching group. It must be `2` to `256` characters in length and must start with a letter or Chinese, but cannot start with `https://` or `https://`.
        :param pulumi.Input[bool] dry_run: The dry run.
        :param pulumi.Input[str] vbr_ha_name: The name of the VBR failover group.
        """
        pulumi.set(__self__, "peer_vbr_id", peer_vbr_id)
        pulumi.set(__self__, "vbr_id", vbr_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dry_run is not None:
            pulumi.set(__self__, "dry_run", dry_run)
        if vbr_ha_name is not None:
            pulumi.set(__self__, "vbr_ha_name", vbr_ha_name)

    @property
    @pulumi.getter(name="peerVbrId")
    def peer_vbr_id(self) -> pulumi.Input[str]:
        """
        The ID of the other VBR in the VBR failover group.
        """
        return pulumi.get(self, "peer_vbr_id")

    @peer_vbr_id.setter
    def peer_vbr_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "peer_vbr_id", value)

    @property
    @pulumi.getter(name="vbrId")
    def vbr_id(self) -> pulumi.Input[str]:
        """
        The ID of the VBR instance.
        """
        return pulumi.get(self, "vbr_id")

    @vbr_id.setter
    def vbr_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "vbr_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the VBR switching group. It must be `2` to `256` characters in length and must start with a letter or Chinese, but cannot start with `https://` or `https://`.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> Optional[pulumi.Input[bool]]:
        """
        The dry run.
        """
        return pulumi.get(self, "dry_run")

    @dry_run.setter
    def dry_run(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dry_run", value)

    @property
    @pulumi.getter(name="vbrHaName")
    def vbr_ha_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the VBR failover group.
        """
        return pulumi.get(self, "vbr_ha_name")

    @vbr_ha_name.setter
    def vbr_ha_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vbr_ha_name", value)


@pulumi.input_type
class _VbrHaState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[str]] = None,
                 dry_run: Optional[pulumi.Input[bool]] = None,
                 peer_vbr_id: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 vbr_ha_name: Optional[pulumi.Input[str]] = None,
                 vbr_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering VbrHa resources.
        :param pulumi.Input[str] description: The description of the VBR switching group. It must be `2` to `256` characters in length and must start with a letter or Chinese, but cannot start with `https://` or `https://`.
        :param pulumi.Input[bool] dry_run: The dry run.
        :param pulumi.Input[str] peer_vbr_id: The ID of the other VBR in the VBR failover group.
        :param pulumi.Input[str] status: The state of the VBR failover group.
        :param pulumi.Input[str] vbr_ha_name: The name of the VBR failover group.
        :param pulumi.Input[str] vbr_id: The ID of the VBR instance.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dry_run is not None:
            pulumi.set(__self__, "dry_run", dry_run)
        if peer_vbr_id is not None:
            pulumi.set(__self__, "peer_vbr_id", peer_vbr_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if vbr_ha_name is not None:
            pulumi.set(__self__, "vbr_ha_name", vbr_ha_name)
        if vbr_id is not None:
            pulumi.set(__self__, "vbr_id", vbr_id)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the VBR switching group. It must be `2` to `256` characters in length and must start with a letter or Chinese, but cannot start with `https://` or `https://`.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> Optional[pulumi.Input[bool]]:
        """
        The dry run.
        """
        return pulumi.get(self, "dry_run")

    @dry_run.setter
    def dry_run(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dry_run", value)

    @property
    @pulumi.getter(name="peerVbrId")
    def peer_vbr_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the other VBR in the VBR failover group.
        """
        return pulumi.get(self, "peer_vbr_id")

    @peer_vbr_id.setter
    def peer_vbr_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "peer_vbr_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The state of the VBR failover group.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="vbrHaName")
    def vbr_ha_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the VBR failover group.
        """
        return pulumi.get(self, "vbr_ha_name")

    @vbr_ha_name.setter
    def vbr_ha_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vbr_ha_name", value)

    @property
    @pulumi.getter(name="vbrId")
    def vbr_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the VBR instance.
        """
        return pulumi.get(self, "vbr_id")

    @vbr_id.setter
    def vbr_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vbr_id", value)


class VbrHa(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 dry_run: Optional[pulumi.Input[bool]] = None,
                 peer_vbr_id: Optional[pulumi.Input[str]] = None,
                 vbr_ha_name: Optional[pulumi.Input[str]] = None,
                 vbr_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a VPC Vbr Ha resource.

        For information about VPC Vbr Ha and how to use it, see [What is Vbr Ha](https://www.alibabacloud.com/help/doc-detail/212629.html).

        > **NOTE:** Available in v1.151.0+.

        ## Import

        VPC Vbr Ha can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:vpc/vbrHa:VbrHa example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: The description of the VBR switching group. It must be `2` to `256` characters in length and must start with a letter or Chinese, but cannot start with `https://` or `https://`.
        :param pulumi.Input[bool] dry_run: The dry run.
        :param pulumi.Input[str] peer_vbr_id: The ID of the other VBR in the VBR failover group.
        :param pulumi.Input[str] vbr_ha_name: The name of the VBR failover group.
        :param pulumi.Input[str] vbr_id: The ID of the VBR instance.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VbrHaArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a VPC Vbr Ha resource.

        For information about VPC Vbr Ha and how to use it, see [What is Vbr Ha](https://www.alibabacloud.com/help/doc-detail/212629.html).

        > **NOTE:** Available in v1.151.0+.

        ## Import

        VPC Vbr Ha can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:vpc/vbrHa:VbrHa example <id>
        ```

        :param str resource_name: The name of the resource.
        :param VbrHaArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VbrHaArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 dry_run: Optional[pulumi.Input[bool]] = None,
                 peer_vbr_id: Optional[pulumi.Input[str]] = None,
                 vbr_ha_name: Optional[pulumi.Input[str]] = None,
                 vbr_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VbrHaArgs.__new__(VbrHaArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["dry_run"] = dry_run
            if peer_vbr_id is None and not opts.urn:
                raise TypeError("Missing required property 'peer_vbr_id'")
            __props__.__dict__["peer_vbr_id"] = peer_vbr_id
            __props__.__dict__["vbr_ha_name"] = vbr_ha_name
            if vbr_id is None and not opts.urn:
                raise TypeError("Missing required property 'vbr_id'")
            __props__.__dict__["vbr_id"] = vbr_id
            __props__.__dict__["status"] = None
        super(VbrHa, __self__).__init__(
            'alicloud:vpc/vbrHa:VbrHa',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[str]] = None,
            dry_run: Optional[pulumi.Input[bool]] = None,
            peer_vbr_id: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            vbr_ha_name: Optional[pulumi.Input[str]] = None,
            vbr_id: Optional[pulumi.Input[str]] = None) -> 'VbrHa':
        """
        Get an existing VbrHa resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: The description of the VBR switching group. It must be `2` to `256` characters in length and must start with a letter or Chinese, but cannot start with `https://` or `https://`.
        :param pulumi.Input[bool] dry_run: The dry run.
        :param pulumi.Input[str] peer_vbr_id: The ID of the other VBR in the VBR failover group.
        :param pulumi.Input[str] status: The state of the VBR failover group.
        :param pulumi.Input[str] vbr_ha_name: The name of the VBR failover group.
        :param pulumi.Input[str] vbr_id: The ID of the VBR instance.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VbrHaState.__new__(_VbrHaState)

        __props__.__dict__["description"] = description
        __props__.__dict__["dry_run"] = dry_run
        __props__.__dict__["peer_vbr_id"] = peer_vbr_id
        __props__.__dict__["status"] = status
        __props__.__dict__["vbr_ha_name"] = vbr_ha_name
        __props__.__dict__["vbr_id"] = vbr_id
        return VbrHa(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the VBR switching group. It must be `2` to `256` characters in length and must start with a letter or Chinese, but cannot start with `https://` or `https://`.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> pulumi.Output[Optional[bool]]:
        """
        The dry run.
        """
        return pulumi.get(self, "dry_run")

    @property
    @pulumi.getter(name="peerVbrId")
    def peer_vbr_id(self) -> pulumi.Output[str]:
        """
        The ID of the other VBR in the VBR failover group.
        """
        return pulumi.get(self, "peer_vbr_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The state of the VBR failover group.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="vbrHaName")
    def vbr_ha_name(self) -> pulumi.Output[Optional[str]]:
        """
        The name of the VBR failover group.
        """
        return pulumi.get(self, "vbr_ha_name")

    @property
    @pulumi.getter(name="vbrId")
    def vbr_id(self) -> pulumi.Output[str]:
        """
        The ID of the VBR instance.
        """
        return pulumi.get(self, "vbr_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['MonitorGroupArgs', 'MonitorGroup']

@pulumi.input_type
class MonitorGroupArgs:
    def __init__(__self__, *,
                 contact_groups: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 monitor_group_name: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, Any]]] = None):
        """
        The set of arguments for constructing a MonitorGroup resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] contact_groups: The alert group to which alert notifications will be sent.
        :param pulumi.Input[str] monitor_group_name: The name of the application group.
        :param pulumi.Input[str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[str] resource_group_name: The name of the resource group.
        """
        if contact_groups is not None:
            pulumi.set(__self__, "contact_groups", contact_groups)
        if monitor_group_name is not None:
            pulumi.set(__self__, "monitor_group_name", monitor_group_name)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if resource_group_name is not None:
            pulumi.set(__self__, "resource_group_name", resource_group_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="contactGroups")
    def contact_groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The alert group to which alert notifications will be sent.
        """
        return pulumi.get(self, "contact_groups")

    @contact_groups.setter
    def contact_groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "contact_groups", value)

    @property
    @pulumi.getter(name="monitorGroupName")
    def monitor_group_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the application group.
        """
        return pulumi.get(self, "monitor_group_name")

    @monitor_group_name.setter
    def monitor_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "monitor_group_name", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the resource group.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _MonitorGroupState:
    def __init__(__self__, *,
                 contact_groups: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 monitor_group_name: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, Any]]] = None):
        """
        Input properties used for looking up and filtering MonitorGroup resources.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] contact_groups: The alert group to which alert notifications will be sent.
        :param pulumi.Input[str] monitor_group_name: The name of the application group.
        :param pulumi.Input[str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[str] resource_group_name: The name of the resource group.
        """
        if contact_groups is not None:
            pulumi.set(__self__, "contact_groups", contact_groups)
        if monitor_group_name is not None:
            pulumi.set(__self__, "monitor_group_name", monitor_group_name)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if resource_group_name is not None:
            pulumi.set(__self__, "resource_group_name", resource_group_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="contactGroups")
    def contact_groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The alert group to which alert notifications will be sent.
        """
        return pulumi.get(self, "contact_groups")

    @contact_groups.setter
    def contact_groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "contact_groups", value)

    @property
    @pulumi.getter(name="monitorGroupName")
    def monitor_group_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the application group.
        """
        return pulumi.get(self, "monitor_group_name")

    @monitor_group_name.setter
    def monitor_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "monitor_group_name", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the resource group.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "tags", value)


class MonitorGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 contact_groups: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 monitor_group_name: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 __props__=None):
        """
        Provides a Cloud Monitor Service Monitor Group resource.

        For information about Cloud Monitor Service Monitor Group and how to use it, see [What is Monitor Group](https://www.alibabacloud.com/help/en/doc-detail/115030.htm).

        > **NOTE:** Available in v1.113.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.cms.MonitorGroup("example", monitor_group_name="tf-testaccmonitorgroup")
        default2 = alicloud.cms.MonitorGroup("default2",
            contact_groups=["your_contact_groups"],
            resource_group_id="your_resource_group_id",
            resource_group_name="resource_group_name",
            tags={
                "Created": "TF",
                "For": "Acceptance-test",
            })
        ```

        ## Import

        Cloud Monitor Service Monitor Group can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:cms/monitorGroup:MonitorGroup example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] contact_groups: The alert group to which alert notifications will be sent.
        :param pulumi.Input[str] monitor_group_name: The name of the application group.
        :param pulumi.Input[str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[str] resource_group_name: The name of the resource group.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[MonitorGroupArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Cloud Monitor Service Monitor Group resource.

        For information about Cloud Monitor Service Monitor Group and how to use it, see [What is Monitor Group](https://www.alibabacloud.com/help/en/doc-detail/115030.htm).

        > **NOTE:** Available in v1.113.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.cms.MonitorGroup("example", monitor_group_name="tf-testaccmonitorgroup")
        default2 = alicloud.cms.MonitorGroup("default2",
            contact_groups=["your_contact_groups"],
            resource_group_id="your_resource_group_id",
            resource_group_name="resource_group_name",
            tags={
                "Created": "TF",
                "For": "Acceptance-test",
            })
        ```

        ## Import

        Cloud Monitor Service Monitor Group can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:cms/monitorGroup:MonitorGroup example <id>
        ```

        :param str resource_name: The name of the resource.
        :param MonitorGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MonitorGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 contact_groups: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 monitor_group_name: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 __props__=None):
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MonitorGroupArgs.__new__(MonitorGroupArgs)

            __props__.__dict__["contact_groups"] = contact_groups
            __props__.__dict__["monitor_group_name"] = monitor_group_name
            __props__.__dict__["resource_group_id"] = resource_group_id
            __props__.__dict__["resource_group_name"] = resource_group_name
            __props__.__dict__["tags"] = tags
        super(MonitorGroup, __self__).__init__(
            'alicloud:cms/monitorGroup:MonitorGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            contact_groups: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            monitor_group_name: Optional[pulumi.Input[str]] = None,
            resource_group_id: Optional[pulumi.Input[str]] = None,
            resource_group_name: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, Any]]] = None) -> 'MonitorGroup':
        """
        Get an existing MonitorGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] contact_groups: The alert group to which alert notifications will be sent.
        :param pulumi.Input[str] monitor_group_name: The name of the application group.
        :param pulumi.Input[str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[str] resource_group_name: The name of the resource group.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MonitorGroupState.__new__(_MonitorGroupState)

        __props__.__dict__["contact_groups"] = contact_groups
        __props__.__dict__["monitor_group_name"] = monitor_group_name
        __props__.__dict__["resource_group_id"] = resource_group_id
        __props__.__dict__["resource_group_name"] = resource_group_name
        __props__.__dict__["tags"] = tags
        return MonitorGroup(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="contactGroups")
    def contact_groups(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        The alert group to which alert notifications will be sent.
        """
        return pulumi.get(self, "contact_groups")

    @property
    @pulumi.getter(name="monitorGroupName")
    def monitor_group_name(self) -> pulumi.Output[str]:
        """
        The name of the application group.
        """
        return pulumi.get(self, "monitor_group_name")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> pulumi.Output[Optional[str]]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Output[Optional[str]]:
        """
        The name of the resource group.
        """
        return pulumi.get(self, "resource_group_name")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, Any]]]:
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['PolicyVersionArgs', 'PolicyVersion']

@pulumi.input_type
class PolicyVersionArgs:
    def __init__(__self__, *,
                 policy_document: pulumi.Input[str],
                 policy_name: pulumi.Input[str],
                 is_default_version: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a PolicyVersion resource.
        :param pulumi.Input[str] policy_document: The content of the policy. The content must be 1 to 2,048 characters in length.
        :param pulumi.Input[str] policy_name: The name of the policy. Name must be 1 to 128 characters in length and can contain letters, digits, and hyphens (-).
        :param pulumi.Input[bool] is_default_version: Specifies whether to set the policy version as the default version. Default to `false`.
        """
        pulumi.set(__self__, "policy_document", policy_document)
        pulumi.set(__self__, "policy_name", policy_name)
        if is_default_version is not None:
            warnings.warn("""Field 'is_default_version' has been deprecated from provider version 1.90.0""", DeprecationWarning)
            pulumi.log.warn("""is_default_version is deprecated: Field 'is_default_version' has been deprecated from provider version 1.90.0""")
        if is_default_version is not None:
            pulumi.set(__self__, "is_default_version", is_default_version)

    @property
    @pulumi.getter(name="policyDocument")
    def policy_document(self) -> pulumi.Input[str]:
        """
        The content of the policy. The content must be 1 to 2,048 characters in length.
        """
        return pulumi.get(self, "policy_document")

    @policy_document.setter
    def policy_document(self, value: pulumi.Input[str]):
        pulumi.set(self, "policy_document", value)

    @property
    @pulumi.getter(name="policyName")
    def policy_name(self) -> pulumi.Input[str]:
        """
        The name of the policy. Name must be 1 to 128 characters in length and can contain letters, digits, and hyphens (-).
        """
        return pulumi.get(self, "policy_name")

    @policy_name.setter
    def policy_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "policy_name", value)

    @property
    @pulumi.getter(name="isDefaultVersion")
    def is_default_version(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to set the policy version as the default version. Default to `false`.
        """
        return pulumi.get(self, "is_default_version")

    @is_default_version.setter
    def is_default_version(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_default_version", value)


@pulumi.input_type
class _PolicyVersionState:
    def __init__(__self__, *,
                 is_default_version: Optional[pulumi.Input[bool]] = None,
                 policy_document: Optional[pulumi.Input[str]] = None,
                 policy_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering PolicyVersion resources.
        :param pulumi.Input[bool] is_default_version: Specifies whether to set the policy version as the default version. Default to `false`.
        :param pulumi.Input[str] policy_document: The content of the policy. The content must be 1 to 2,048 characters in length.
        :param pulumi.Input[str] policy_name: The name of the policy. Name must be 1 to 128 characters in length and can contain letters, digits, and hyphens (-).
        """
        if is_default_version is not None:
            warnings.warn("""Field 'is_default_version' has been deprecated from provider version 1.90.0""", DeprecationWarning)
            pulumi.log.warn("""is_default_version is deprecated: Field 'is_default_version' has been deprecated from provider version 1.90.0""")
        if is_default_version is not None:
            pulumi.set(__self__, "is_default_version", is_default_version)
        if policy_document is not None:
            pulumi.set(__self__, "policy_document", policy_document)
        if policy_name is not None:
            pulumi.set(__self__, "policy_name", policy_name)

    @property
    @pulumi.getter(name="isDefaultVersion")
    def is_default_version(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to set the policy version as the default version. Default to `false`.
        """
        return pulumi.get(self, "is_default_version")

    @is_default_version.setter
    def is_default_version(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_default_version", value)

    @property
    @pulumi.getter(name="policyDocument")
    def policy_document(self) -> Optional[pulumi.Input[str]]:
        """
        The content of the policy. The content must be 1 to 2,048 characters in length.
        """
        return pulumi.get(self, "policy_document")

    @policy_document.setter
    def policy_document(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "policy_document", value)

    @property
    @pulumi.getter(name="policyName")
    def policy_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the policy. Name must be 1 to 128 characters in length and can contain letters, digits, and hyphens (-).
        """
        return pulumi.get(self, "policy_name")

    @policy_name.setter
    def policy_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "policy_name", value)


class PolicyVersion(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 is_default_version: Optional[pulumi.Input[bool]] = None,
                 policy_document: Optional[pulumi.Input[str]] = None,
                 policy_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example_policy = alicloud.resourcemanager.Policy("examplePolicy",
            policy_name="tftest",
            policy_document=\"\"\"		{
        			"Statement": [{
        				"Action": ["oss:*"],
        				"Effect": "Allow",
        				"Resource": ["acs:oss:*:*:*"]
        			}],
        			"Version": "1"
        		}
        \"\"\")
        example_policy_version = alicloud.resourcemanager.PolicyVersion("examplePolicyVersion",
            policy_name=example_policy.policy_name,
            policy_document=\"\"\"		{
        			"Statement": [{
        				"Action": ["oss:*"],
        				"Effect": "Allow",
        				"Resource": ["acs:oss:*:*:myphotos"]
        			}],
        			"Version": "1"
        		}
        \"\"\")
        ```

        ## Import

        Resource Manager Policy Version can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:resourcemanager/policyVersion:PolicyVersion example tftest:v2
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] is_default_version: Specifies whether to set the policy version as the default version. Default to `false`.
        :param pulumi.Input[str] policy_document: The content of the policy. The content must be 1 to 2,048 characters in length.
        :param pulumi.Input[str] policy_name: The name of the policy. Name must be 1 to 128 characters in length and can contain letters, digits, and hyphens (-).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PolicyVersionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example_policy = alicloud.resourcemanager.Policy("examplePolicy",
            policy_name="tftest",
            policy_document=\"\"\"		{
        			"Statement": [{
        				"Action": ["oss:*"],
        				"Effect": "Allow",
        				"Resource": ["acs:oss:*:*:*"]
        			}],
        			"Version": "1"
        		}
        \"\"\")
        example_policy_version = alicloud.resourcemanager.PolicyVersion("examplePolicyVersion",
            policy_name=example_policy.policy_name,
            policy_document=\"\"\"		{
        			"Statement": [{
        				"Action": ["oss:*"],
        				"Effect": "Allow",
        				"Resource": ["acs:oss:*:*:myphotos"]
        			}],
        			"Version": "1"
        		}
        \"\"\")
        ```

        ## Import

        Resource Manager Policy Version can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:resourcemanager/policyVersion:PolicyVersion example tftest:v2
        ```

        :param str resource_name: The name of the resource.
        :param PolicyVersionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PolicyVersionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 is_default_version: Optional[pulumi.Input[bool]] = None,
                 policy_document: Optional[pulumi.Input[str]] = None,
                 policy_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PolicyVersionArgs.__new__(PolicyVersionArgs)

            if is_default_version is not None and not opts.urn:
                warnings.warn("""Field 'is_default_version' has been deprecated from provider version 1.90.0""", DeprecationWarning)
                pulumi.log.warn("""is_default_version is deprecated: Field 'is_default_version' has been deprecated from provider version 1.90.0""")
            __props__.__dict__["is_default_version"] = is_default_version
            if policy_document is None and not opts.urn:
                raise TypeError("Missing required property 'policy_document'")
            __props__.__dict__["policy_document"] = policy_document
            if policy_name is None and not opts.urn:
                raise TypeError("Missing required property 'policy_name'")
            __props__.__dict__["policy_name"] = policy_name
        super(PolicyVersion, __self__).__init__(
            'alicloud:resourcemanager/policyVersion:PolicyVersion',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            is_default_version: Optional[pulumi.Input[bool]] = None,
            policy_document: Optional[pulumi.Input[str]] = None,
            policy_name: Optional[pulumi.Input[str]] = None) -> 'PolicyVersion':
        """
        Get an existing PolicyVersion resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] is_default_version: Specifies whether to set the policy version as the default version. Default to `false`.
        :param pulumi.Input[str] policy_document: The content of the policy. The content must be 1 to 2,048 characters in length.
        :param pulumi.Input[str] policy_name: The name of the policy. Name must be 1 to 128 characters in length and can contain letters, digits, and hyphens (-).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PolicyVersionState.__new__(_PolicyVersionState)

        __props__.__dict__["is_default_version"] = is_default_version
        __props__.__dict__["policy_document"] = policy_document
        __props__.__dict__["policy_name"] = policy_name
        return PolicyVersion(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="isDefaultVersion")
    def is_default_version(self) -> pulumi.Output[Optional[bool]]:
        """
        Specifies whether to set the policy version as the default version. Default to `false`.
        """
        return pulumi.get(self, "is_default_version")

    @property
    @pulumi.getter(name="policyDocument")
    def policy_document(self) -> pulumi.Output[str]:
        """
        The content of the policy. The content must be 1 to 2,048 characters in length.
        """
        return pulumi.get(self, "policy_document")

    @property
    @pulumi.getter(name="policyName")
    def policy_name(self) -> pulumi.Output[str]:
        """
        The name of the policy. Name must be 1 to 128 characters in length and can contain letters, digits, and hyphens (-).
        """
        return pulumi.get(self, "policy_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetLifecyclePoliciesResult',
    'AwaitableGetLifecyclePoliciesResult',
    'get_lifecycle_policies',
    'get_lifecycle_policies_output',
]

@pulumi.output_type
class GetLifecyclePoliciesResult:
    """
    A collection of values returned by getLifecyclePolicies.
    """
    def __init__(__self__, file_system_id=None, id=None, ids=None, name_regex=None, names=None, output_file=None, policies=None):
        if file_system_id and not isinstance(file_system_id, str):
            raise TypeError("Expected argument 'file_system_id' to be a str")
        pulumi.set(__self__, "file_system_id", file_system_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if policies and not isinstance(policies, list):
            raise TypeError("Expected argument 'policies' to be a list")
        pulumi.set(__self__, "policies", policies)

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> str:
        return pulumi.get(self, "file_system_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def policies(self) -> Sequence['outputs.GetLifecyclePoliciesPolicyResult']:
        return pulumi.get(self, "policies")


class AwaitableGetLifecyclePoliciesResult(GetLifecyclePoliciesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetLifecyclePoliciesResult(
            file_system_id=self.file_system_id,
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            policies=self.policies)


def get_lifecycle_policies(file_system_id: Optional[str] = None,
                           ids: Optional[Sequence[str]] = None,
                           name_regex: Optional[str] = None,
                           output_file: Optional[str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetLifecyclePoliciesResult:
    """
    This data source provides the Nas Lifecycle Policies of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.153.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.nas.get_lifecycle_policies(file_system_id="example_value",
        ids=[
            "my-LifecyclePolicy-1",
            "my-LifecyclePolicy-2",
        ])
    pulumi.export("nasLifecyclePolicyId1", ids.policies[0].id)
    name_regex = alicloud.nas.get_lifecycle_policies(file_system_id="example_value",
        name_regex="^my-LifecyclePolicy")
    pulumi.export("nasLifecyclePolicyId2", name_regex.policies[0].id)
    ```


    :param str file_system_id: The ID of the file system.
    :param Sequence[str] ids: A list of Lifecycle Policy IDs.
    :param str name_regex: A regex string to filter results by Lifecycle Policy name.
    """
    __args__ = dict()
    __args__['fileSystemId'] = file_system_id
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = _utilities.get_version()
    __ret__ = pulumi.runtime.invoke('alicloud:nas/getLifecyclePolicies:getLifecyclePolicies', __args__, opts=opts, typ=GetLifecyclePoliciesResult).value

    return AwaitableGetLifecyclePoliciesResult(
        file_system_id=__ret__.file_system_id,
        id=__ret__.id,
        ids=__ret__.ids,
        name_regex=__ret__.name_regex,
        names=__ret__.names,
        output_file=__ret__.output_file,
        policies=__ret__.policies)


@_utilities.lift_output_func(get_lifecycle_policies)
def get_lifecycle_policies_output(file_system_id: Optional[pulumi.Input[str]] = None,
                                  ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                  name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                                  output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetLifecyclePoliciesResult]:
    """
    This data source provides the Nas Lifecycle Policies of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.153.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.nas.get_lifecycle_policies(file_system_id="example_value",
        ids=[
            "my-LifecyclePolicy-1",
            "my-LifecyclePolicy-2",
        ])
    pulumi.export("nasLifecyclePolicyId1", ids.policies[0].id)
    name_regex = alicloud.nas.get_lifecycle_policies(file_system_id="example_value",
        name_regex="^my-LifecyclePolicy")
    pulumi.export("nasLifecyclePolicyId2", name_regex.policies[0].id)
    ```


    :param str file_system_id: The ID of the file system.
    :param Sequence[str] ids: A list of Lifecycle Policy IDs.
    :param str name_regex: A regex string to filter results by Lifecycle Policy name.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'ApplicationInternetArgs',
    'ApplicationIntranetArgs',
    'IngressDefaultRuleArgs',
    'IngressRuleArgs',
]

@pulumi.input_type
class ApplicationInternetArgs:
    def __init__(__self__, *,
                 https_cert_id: Optional[pulumi.Input[str]] = None,
                 port: Optional[pulumi.Input[int]] = None,
                 protocol: Optional[pulumi.Input[str]] = None,
                 target_port: Optional[pulumi.Input[int]] = None):
        """
        :param pulumi.Input[str] https_cert_id: SSL certificate. `https_cert_id` is required when HTTPS is selected
        :param pulumi.Input[int] port: SLB Port.
        :param pulumi.Input[str] protocol: Network protocol. Valid values: `TCP` ,`HTTP`,`HTTPS`.
        :param pulumi.Input[int] target_port: Container port.
        """
        if https_cert_id is not None:
            pulumi.set(__self__, "https_cert_id", https_cert_id)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if target_port is not None:
            pulumi.set(__self__, "target_port", target_port)

    @property
    @pulumi.getter(name="httpsCertId")
    def https_cert_id(self) -> Optional[pulumi.Input[str]]:
        """
        SSL certificate. `https_cert_id` is required when HTTPS is selected
        """
        return pulumi.get(self, "https_cert_id")

    @https_cert_id.setter
    def https_cert_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "https_cert_id", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[int]]:
        """
        SLB Port.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[str]]:
        """
        Network protocol. Valid values: `TCP` ,`HTTP`,`HTTPS`.
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="targetPort")
    def target_port(self) -> Optional[pulumi.Input[int]]:
        """
        Container port.
        """
        return pulumi.get(self, "target_port")

    @target_port.setter
    def target_port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "target_port", value)


@pulumi.input_type
class ApplicationIntranetArgs:
    def __init__(__self__, *,
                 https_cert_id: Optional[pulumi.Input[str]] = None,
                 port: Optional[pulumi.Input[int]] = None,
                 protocol: Optional[pulumi.Input[str]] = None,
                 target_port: Optional[pulumi.Input[int]] = None):
        """
        :param pulumi.Input[str] https_cert_id: SSL certificate. `https_cert_id` is required when HTTPS is selected
        :param pulumi.Input[int] port: SLB Port.
        :param pulumi.Input[str] protocol: Network protocol. Valid values: `TCP` ,`HTTP`,`HTTPS`.
        :param pulumi.Input[int] target_port: Container port.
        """
        if https_cert_id is not None:
            pulumi.set(__self__, "https_cert_id", https_cert_id)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if target_port is not None:
            pulumi.set(__self__, "target_port", target_port)

    @property
    @pulumi.getter(name="httpsCertId")
    def https_cert_id(self) -> Optional[pulumi.Input[str]]:
        """
        SSL certificate. `https_cert_id` is required when HTTPS is selected
        """
        return pulumi.get(self, "https_cert_id")

    @https_cert_id.setter
    def https_cert_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "https_cert_id", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[int]]:
        """
        SLB Port.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[str]]:
        """
        Network protocol. Valid values: `TCP` ,`HTTP`,`HTTPS`.
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="targetPort")
    def target_port(self) -> Optional[pulumi.Input[int]]:
        """
        Container port.
        """
        return pulumi.get(self, "target_port")

    @target_port.setter
    def target_port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "target_port", value)


@pulumi.input_type
class IngressDefaultRuleArgs:
    def __init__(__self__, *,
                 app_id: Optional[pulumi.Input[str]] = None,
                 app_name: Optional[pulumi.Input[str]] = None,
                 container_port: Optional[pulumi.Input[int]] = None):
        """
        :param pulumi.Input[str] app_id: Target application ID.
        :param pulumi.Input[str] app_name: Target application name.
        :param pulumi.Input[int] container_port: Application backend port.
        """
        if app_id is not None:
            pulumi.set(__self__, "app_id", app_id)
        if app_name is not None:
            pulumi.set(__self__, "app_name", app_name)
        if container_port is not None:
            pulumi.set(__self__, "container_port", container_port)

    @property
    @pulumi.getter(name="appId")
    def app_id(self) -> Optional[pulumi.Input[str]]:
        """
        Target application ID.
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "app_id", value)

    @property
    @pulumi.getter(name="appName")
    def app_name(self) -> Optional[pulumi.Input[str]]:
        """
        Target application name.
        """
        return pulumi.get(self, "app_name")

    @app_name.setter
    def app_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "app_name", value)

    @property
    @pulumi.getter(name="containerPort")
    def container_port(self) -> Optional[pulumi.Input[int]]:
        """
        Application backend port.
        """
        return pulumi.get(self, "container_port")

    @container_port.setter
    def container_port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "container_port", value)


@pulumi.input_type
class IngressRuleArgs:
    def __init__(__self__, *,
                 app_id: pulumi.Input[str],
                 app_name: pulumi.Input[str],
                 container_port: pulumi.Input[int],
                 domain: pulumi.Input[str],
                 path: pulumi.Input[str]):
        """
        :param pulumi.Input[str] app_id: Target application ID.
        :param pulumi.Input[str] app_name: Target application name.
        :param pulumi.Input[int] container_port: Application backend port.
        :param pulumi.Input[str] domain: Application domain name.
        :param pulumi.Input[str] path: URL path.
        """
        pulumi.set(__self__, "app_id", app_id)
        pulumi.set(__self__, "app_name", app_name)
        pulumi.set(__self__, "container_port", container_port)
        pulumi.set(__self__, "domain", domain)
        pulumi.set(__self__, "path", path)

    @property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Input[str]:
        """
        Target application ID.
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "app_id", value)

    @property
    @pulumi.getter(name="appName")
    def app_name(self) -> pulumi.Input[str]:
        """
        Target application name.
        """
        return pulumi.get(self, "app_name")

    @app_name.setter
    def app_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "app_name", value)

    @property
    @pulumi.getter(name="containerPort")
    def container_port(self) -> pulumi.Input[int]:
        """
        Application backend port.
        """
        return pulumi.get(self, "container_port")

    @container_port.setter
    def container_port(self, value: pulumi.Input[int]):
        pulumi.set(self, "container_port", value)

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Input[str]:
        """
        Application domain name.
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: pulumi.Input[str]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter
    def path(self) -> pulumi.Input[str]:
        """
        URL path.
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: pulumi.Input[str]):
        pulumi.set(self, "path", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['AnycastEipAddressAttachmentArgs', 'AnycastEipAddressAttachment']

@pulumi.input_type
class AnycastEipAddressAttachmentArgs:
    def __init__(__self__, *,
                 anycast_id: pulumi.Input[str],
                 bind_instance_id: pulumi.Input[str],
                 bind_instance_region_id: pulumi.Input[str],
                 bind_instance_type: pulumi.Input[str]):
        """
        The set of arguments for constructing a AnycastEipAddressAttachment resource.
        :param pulumi.Input[str] anycast_id: The ID of Anycast EIP.
        :param pulumi.Input[str] bind_instance_id: The ID of bound instance.
        :param pulumi.Input[str] bind_instance_region_id: The region ID of bound instance.
        :param pulumi.Input[str] bind_instance_type: The type of bound instance. Valid value: `SlbInstance`.
        """
        pulumi.set(__self__, "anycast_id", anycast_id)
        pulumi.set(__self__, "bind_instance_id", bind_instance_id)
        pulumi.set(__self__, "bind_instance_region_id", bind_instance_region_id)
        pulumi.set(__self__, "bind_instance_type", bind_instance_type)

    @property
    @pulumi.getter(name="anycastId")
    def anycast_id(self) -> pulumi.Input[str]:
        """
        The ID of Anycast EIP.
        """
        return pulumi.get(self, "anycast_id")

    @anycast_id.setter
    def anycast_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "anycast_id", value)

    @property
    @pulumi.getter(name="bindInstanceId")
    def bind_instance_id(self) -> pulumi.Input[str]:
        """
        The ID of bound instance.
        """
        return pulumi.get(self, "bind_instance_id")

    @bind_instance_id.setter
    def bind_instance_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "bind_instance_id", value)

    @property
    @pulumi.getter(name="bindInstanceRegionId")
    def bind_instance_region_id(self) -> pulumi.Input[str]:
        """
        The region ID of bound instance.
        """
        return pulumi.get(self, "bind_instance_region_id")

    @bind_instance_region_id.setter
    def bind_instance_region_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "bind_instance_region_id", value)

    @property
    @pulumi.getter(name="bindInstanceType")
    def bind_instance_type(self) -> pulumi.Input[str]:
        """
        The type of bound instance. Valid value: `SlbInstance`.
        """
        return pulumi.get(self, "bind_instance_type")

    @bind_instance_type.setter
    def bind_instance_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "bind_instance_type", value)


@pulumi.input_type
class _AnycastEipAddressAttachmentState:
    def __init__(__self__, *,
                 anycast_id: Optional[pulumi.Input[str]] = None,
                 bind_instance_id: Optional[pulumi.Input[str]] = None,
                 bind_instance_region_id: Optional[pulumi.Input[str]] = None,
                 bind_instance_type: Optional[pulumi.Input[str]] = None,
                 bind_time: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering AnycastEipAddressAttachment resources.
        :param pulumi.Input[str] anycast_id: The ID of Anycast EIP.
        :param pulumi.Input[str] bind_instance_id: The ID of bound instance.
        :param pulumi.Input[str] bind_instance_region_id: The region ID of bound instance.
        :param pulumi.Input[str] bind_instance_type: The type of bound instance. Valid value: `SlbInstance`.
        :param pulumi.Input[str] bind_time: The time of bound instance.
        """
        if anycast_id is not None:
            pulumi.set(__self__, "anycast_id", anycast_id)
        if bind_instance_id is not None:
            pulumi.set(__self__, "bind_instance_id", bind_instance_id)
        if bind_instance_region_id is not None:
            pulumi.set(__self__, "bind_instance_region_id", bind_instance_region_id)
        if bind_instance_type is not None:
            pulumi.set(__self__, "bind_instance_type", bind_instance_type)
        if bind_time is not None:
            pulumi.set(__self__, "bind_time", bind_time)

    @property
    @pulumi.getter(name="anycastId")
    def anycast_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of Anycast EIP.
        """
        return pulumi.get(self, "anycast_id")

    @anycast_id.setter
    def anycast_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "anycast_id", value)

    @property
    @pulumi.getter(name="bindInstanceId")
    def bind_instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of bound instance.
        """
        return pulumi.get(self, "bind_instance_id")

    @bind_instance_id.setter
    def bind_instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bind_instance_id", value)

    @property
    @pulumi.getter(name="bindInstanceRegionId")
    def bind_instance_region_id(self) -> Optional[pulumi.Input[str]]:
        """
        The region ID of bound instance.
        """
        return pulumi.get(self, "bind_instance_region_id")

    @bind_instance_region_id.setter
    def bind_instance_region_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bind_instance_region_id", value)

    @property
    @pulumi.getter(name="bindInstanceType")
    def bind_instance_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of bound instance. Valid value: `SlbInstance`.
        """
        return pulumi.get(self, "bind_instance_type")

    @bind_instance_type.setter
    def bind_instance_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bind_instance_type", value)

    @property
    @pulumi.getter(name="bindTime")
    def bind_time(self) -> Optional[pulumi.Input[str]]:
        """
        The time of bound instance.
        """
        return pulumi.get(self, "bind_time")

    @bind_time.setter
    def bind_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bind_time", value)


class AnycastEipAddressAttachment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 anycast_id: Optional[pulumi.Input[str]] = None,
                 bind_instance_id: Optional[pulumi.Input[str]] = None,
                 bind_instance_region_id: Optional[pulumi.Input[str]] = None,
                 bind_instance_type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Eipanycast Anycast Eip Address Attachment resource.

        For information about Eipanycast Anycast Eip Address Attachment and how to use it, see [What is Anycast Eip Address Attachment](https://help.aliyun.com/document_detail/171857.html).

        > **NOTE:** Available in v1.113.0+.

        > **NOTE:** The following regions support currently while Slb instance support bound.
        [eu-west-1-gb33-a01,cn-hongkong-am4-c04,ap-southeast-os30-a01,us-west-ot7-a01,ap-south-in73-a01,ap-southeast-my88-a01]

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example_anycast_eip_address = alicloud.eipanycast.AnycastEipAddress("exampleAnycastEipAddress", service_location="international")
        example_anycast_eip_address_attachment = alicloud.eipanycast.AnycastEipAddressAttachment("exampleAnycastEipAddressAttachment",
            anycast_id=example_anycast_eip_address.id,
            bind_instance_id="lb-j6chlcr8lffy7********",
            bind_instance_region_id="cn-hongkong",
            bind_instance_type="SlbInstance")
        ```

        ## Import

        Eipanycast Anycast Eip Address Attachment can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:eipanycast/anycastEipAddressAttachment:AnycastEipAddressAttachment example `anycast_id`:`bind_instance_id`:`bind_instance_region_id`:`bind_instance_type`
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] anycast_id: The ID of Anycast EIP.
        :param pulumi.Input[str] bind_instance_id: The ID of bound instance.
        :param pulumi.Input[str] bind_instance_region_id: The region ID of bound instance.
        :param pulumi.Input[str] bind_instance_type: The type of bound instance. Valid value: `SlbInstance`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AnycastEipAddressAttachmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Eipanycast Anycast Eip Address Attachment resource.

        For information about Eipanycast Anycast Eip Address Attachment and how to use it, see [What is Anycast Eip Address Attachment](https://help.aliyun.com/document_detail/171857.html).

        > **NOTE:** Available in v1.113.0+.

        > **NOTE:** The following regions support currently while Slb instance support bound.
        [eu-west-1-gb33-a01,cn-hongkong-am4-c04,ap-southeast-os30-a01,us-west-ot7-a01,ap-south-in73-a01,ap-southeast-my88-a01]

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example_anycast_eip_address = alicloud.eipanycast.AnycastEipAddress("exampleAnycastEipAddress", service_location="international")
        example_anycast_eip_address_attachment = alicloud.eipanycast.AnycastEipAddressAttachment("exampleAnycastEipAddressAttachment",
            anycast_id=example_anycast_eip_address.id,
            bind_instance_id="lb-j6chlcr8lffy7********",
            bind_instance_region_id="cn-hongkong",
            bind_instance_type="SlbInstance")
        ```

        ## Import

        Eipanycast Anycast Eip Address Attachment can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:eipanycast/anycastEipAddressAttachment:AnycastEipAddressAttachment example `anycast_id`:`bind_instance_id`:`bind_instance_region_id`:`bind_instance_type`
        ```

        :param str resource_name: The name of the resource.
        :param AnycastEipAddressAttachmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AnycastEipAddressAttachmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 anycast_id: Optional[pulumi.Input[str]] = None,
                 bind_instance_id: Optional[pulumi.Input[str]] = None,
                 bind_instance_region_id: Optional[pulumi.Input[str]] = None,
                 bind_instance_type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AnycastEipAddressAttachmentArgs.__new__(AnycastEipAddressAttachmentArgs)

            if anycast_id is None and not opts.urn:
                raise TypeError("Missing required property 'anycast_id'")
            __props__.__dict__["anycast_id"] = anycast_id
            if bind_instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'bind_instance_id'")
            __props__.__dict__["bind_instance_id"] = bind_instance_id
            if bind_instance_region_id is None and not opts.urn:
                raise TypeError("Missing required property 'bind_instance_region_id'")
            __props__.__dict__["bind_instance_region_id"] = bind_instance_region_id
            if bind_instance_type is None and not opts.urn:
                raise TypeError("Missing required property 'bind_instance_type'")
            __props__.__dict__["bind_instance_type"] = bind_instance_type
            __props__.__dict__["bind_time"] = None
        super(AnycastEipAddressAttachment, __self__).__init__(
            'alicloud:eipanycast/anycastEipAddressAttachment:AnycastEipAddressAttachment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            anycast_id: Optional[pulumi.Input[str]] = None,
            bind_instance_id: Optional[pulumi.Input[str]] = None,
            bind_instance_region_id: Optional[pulumi.Input[str]] = None,
            bind_instance_type: Optional[pulumi.Input[str]] = None,
            bind_time: Optional[pulumi.Input[str]] = None) -> 'AnycastEipAddressAttachment':
        """
        Get an existing AnycastEipAddressAttachment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] anycast_id: The ID of Anycast EIP.
        :param pulumi.Input[str] bind_instance_id: The ID of bound instance.
        :param pulumi.Input[str] bind_instance_region_id: The region ID of bound instance.
        :param pulumi.Input[str] bind_instance_type: The type of bound instance. Valid value: `SlbInstance`.
        :param pulumi.Input[str] bind_time: The time of bound instance.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AnycastEipAddressAttachmentState.__new__(_AnycastEipAddressAttachmentState)

        __props__.__dict__["anycast_id"] = anycast_id
        __props__.__dict__["bind_instance_id"] = bind_instance_id
        __props__.__dict__["bind_instance_region_id"] = bind_instance_region_id
        __props__.__dict__["bind_instance_type"] = bind_instance_type
        __props__.__dict__["bind_time"] = bind_time
        return AnycastEipAddressAttachment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="anycastId")
    def anycast_id(self) -> pulumi.Output[str]:
        """
        The ID of Anycast EIP.
        """
        return pulumi.get(self, "anycast_id")

    @property
    @pulumi.getter(name="bindInstanceId")
    def bind_instance_id(self) -> pulumi.Output[str]:
        """
        The ID of bound instance.
        """
        return pulumi.get(self, "bind_instance_id")

    @property
    @pulumi.getter(name="bindInstanceRegionId")
    def bind_instance_region_id(self) -> pulumi.Output[str]:
        """
        The region ID of bound instance.
        """
        return pulumi.get(self, "bind_instance_region_id")

    @property
    @pulumi.getter(name="bindInstanceType")
    def bind_instance_type(self) -> pulumi.Output[str]:
        """
        The type of bound instance. Valid value: `SlbInstance`.
        """
        return pulumi.get(self, "bind_instance_type")

    @property
    @pulumi.getter(name="bindTime")
    def bind_time(self) -> pulumi.Output[str]:
        """
        The time of bound instance.
        """
        return pulumi.get(self, "bind_time")

